@@ -25,6 +25,7 @@
 #include <QHBoxLayout>
 #include <QTextCodec>
 #include <QDebug>
+#include <QComboBox>
 
 #include <DStandardItem>
 #include <DTitlebar>
@@ -149,21 +150,43 @@ MainWindow::MainWindow(QWidget *parent)
     m_pListView->setCurrentIndex(m_pListViewModel->index(0, 0));
 }
 
+#if 1
+#define AsynPreview
+#endif
+
 void MainWindow::menuItemInvoked(QAction *action)
 {
     if (action->text() == "testPrinter") {
+// 下面注释的目的用于在 QDoc 生成文档是能够直接使用 \snippet 命令选取这段代码进行展示
+//! [0]
         DPrintPreviewDialog dialog(this);
-        connect(&dialog, &DPrintPreviewDialog::paintRequested,
+        //测试保存PDF文件名称接口
+        dialog.setDocName("test");
+#ifdef AsynPreview
+        dialog.setAsynPreview(31);
+        connect(&dialog, QOverload<DPrinter *, const QVector<int> &>::of(&DPrintPreviewDialog::paintRequested),
+#else
+        connect(&dialog, QOverload<DPrinter *>::of(&DPrintPreviewDialog::paintRequested),
+#endif
+#ifdef AsynPreview
+                this, [=](DPrinter *_printer, const QVector<int> &pageRange) {
+#else
                 this, [=](DPrinter *_printer) {
+#endif
                     // 此函数内代码为调试打印内容代码，调整较随意！
-                    _printer->setFromTo(1, 10);
+                    _printer->setFromTo(1, 31);
                     QPainter painter(_printer);
                     bool firstPage = true;
                     for (int page = _printer->fromPage(); page <= _printer->toPage(); ++page) {
+#ifdef AsynPreview
+                        if (!pageRange.contains(page))
+                            continue;
+#endif
+
                         painter.resetTransform();
                         if (!firstPage)
                             _printer->newPage();
-                        qApp->processEvents();
+                        // qApp->processEvents();
 
                         // 给出调用方widget界面作为打印内容
                         double xscale = _printer->pageRect().width() / double(this->width());
@@ -193,15 +216,16 @@ void MainWindow::menuItemInvoked(QAction *action)
                     }
                 });
         dialog.exec();
+//! [0]
         return;
     }
     if (action->text() == "dfm-settings") {
         QTemporaryFile tmpFile;
         tmpFile.open();
-        auto backend = new Dtk::Core::QSettingBackend(tmpFile.fileName());
+        Dtk::Core::QSettingBackend backend(tmpFile.fileName());
 
         auto settings = Dtk::Core::DSettings::fromJsonFile(":/resources/data/dfm-settings.json");
-        settings->setBackend(backend);
+        settings->setBackend(&backend);
 
         DSettingsDialog dsd(this);
         dsd.updateSettings(settings);
@@ -212,10 +236,10 @@ void MainWindow::menuItemInvoked(QAction *action)
     if (action->text() == "dt-settings") {
         QTemporaryFile tmpFile;
         tmpFile.open();
-        auto backend = new Dtk::Core::QSettingBackend(tmpFile.fileName());
+        Dtk::Core::QSettingBackend backend(tmpFile.fileName());
 
         auto settings = Dtk::Core::DSettings::fromJsonFile(":/resources/data/dt-settings.json");
-        settings->setBackend(backend);
+        settings->setBackend(&backend);
 
         QFontDatabase fontDatabase;
         auto fontFamliy = settings->option("base.font.family");
@@ -259,6 +283,27 @@ void MainWindow::menuItemInvoked(QAction *action)
 
             return nullptr;
         });
+
+        // 测试DSettingsDialog::setGroupVisible接口
+        auto hLayout = dsd.layout();
+        auto test = new QWidget;
+        auto layout = new QHBoxLayout(test);
+        auto testBtn = new QPushButton();
+        testBtn->setText("test setGroupVisible");
+        auto combobox = new QComboBox();
+        combobox->addItem("base");
+        combobox->addItem("base.custom-widgets");
+        combobox->addItem("base.theme");
+        combobox->addItem("shortcuts");
+        combobox->addItem("advance");
+        layout->addWidget(combobox);
+        layout->addWidget(testBtn);
+        hLayout->addWidget(test);
+        connect(testBtn, &QPushButton::clicked, [&dsd, combobox](){
+            auto key = combobox->currentText();
+            dsd.setGroupVisible(key, !dsd.groupIsVisible(key));
+        });
+
         dsd.updateSettings(settings);
         dsd.exec();
         return;
