@@ -15,12 +15,12 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef DTRASHMANAGER_H
-#define DTRASHMANAGER_H
+#ifndef DTKWIDGET_DTRASHMANAGER_H
+#define DTKWIDGET_DTRASHMANAGER_H
 
 #include <DObject>
 
-#include "dtkwidget_global.h"
+#include <dtkwidget_global.h>
 
 #include <QObject>
 
@@ -45,4 +45,4 @@ private:
 
 DWIDGET_END_NAMESPACE
 
-#endif // DTRASHMANAGER_H
+#endif // DTKWIDGET_DTRASHMANAGER_H
