@@ -18,7 +18,7 @@
 #ifndef DABOUTDIALOG_H
 #define DABOUTDIALOG_H
 
-#include "ddialog.h"
+#include <DDialog>
 
 DWIDGET_BEGIN_NAMESPACE
 
