@@ -51,32 +51,26 @@ int ArrowButtonIcon::buttonState() const
 }
 
 /*!
-    \~chinese \class DArrowButton
-    \~chinese \brief 可以使用 DArrowButton 类快速创建箭头形状的按钮。
+  \class Dtk::Widget::DArrowButton
+  \inmodule dtkwidget
+  \brief 可以使用 DArrowButton 类快速创建箭头形状的按钮.
+  \brief DArrowButton allowed you create button with arrow icon conveniently.
 
-    \~chinese \image html DArrowButton.png
+  \image html DArrowButton.png
 
-    \~chinese DArrowButton 提供了快速的方式创建包含箭头标识的按钮，并允许通过 setArrowDirection() 设置箭头方向来直接改按钮的箭头图标的方向。
-    此外，还可以通过 \ref arrowButtonDirection 和 \ref arrowButtonState 属性获取和修改箭头按钮的状态。
+  DArrowButton 提供了快速的方式创建包含箭头标识的按钮，并允许通过 setArrowDirection() 设置箭头方向来直接改按钮的箭头图标的方向。
+  此外，还可以通过 arrowButtonDirection 和 arrowButtonState 属性获取和修改箭头按钮的状态。
+  You can use DArrowButton to create button with arrow icon, and it also allowed you update the arrow direction by
+  calling setArrowDirection() . You can also update arrow state via arrowButtonDirection and arrowButtonState property.
 
-    \~chinese \sa QLabel
+  \sa QLabel
 */
 
 /*!
-    \~english \class DArrowButton
-    \~english \brief DArrowButton allowed you create button with arrow icon conveniently.
+  \brief Construct a new DArrowButton with DArrowButton::ArrowDown direction
+  \brief 构造一个 DArrowButton 箭头按钮，默认箭头方向向下
 
-    \~english \image html DArrowButton.png
-
-    \~english You can use DArrowButton to create button with arrow icon, and it also allowed you update the arrow direction by
-    calling setArrowDirection() . You can also update arrow state via arrowButtonDirection and arrowButtonState property.
-
-    \~english \sa QLabel
-*/
-
-/*!
- * \~english \brief Construct a new DArrowButton with DArrowButton::ArrowDown direction
- * \~chinese \brief 构造一个 DArrowButton 箭头按钮，默认箭头方向向下
+  \a parent 父控件指针.
  */
 DArrowButton::DArrowButton(QWidget *parent)
     : QLabel(parent)
@@ -84,17 +78,20 @@ DArrowButton::DArrowButton(QWidget *parent)
     setFixedSize(IMAGE_BUTTON_WIDTH, BUTTON_HEIGHT);
 
     m_normalLabel = new ArrowButtonIcon(this);
+    m_normalLabel->setAccessibleName("DArrowButtonNormalLabel");
     m_normalLabel->setObjectName("ArrowButtonIconNormal");
     m_normalLabel->setFixedSize(size());
     m_normalLabel->move(0, 0);
 
     m_hoverLabel = new ArrowButtonIcon(this);
+    m_hoverLabel->setAccessibleName("DArrowButtonHoverLabel");
     m_hoverLabel->setObjectName("ArrowButtonIconHover");
     m_hoverLabel->setFixedSize(size());
     m_hoverLabel->move(0, 0);
     m_hoverLabel->setVisible(false);
 
     m_pressLabel = new ArrowButtonIcon(this);
+    m_pressLabel->setAccessibleName("DArrowButtonPressedLabel");
     m_pressLabel->setObjectName("ArrowButtonIconPress");
     m_pressLabel->setFixedSize(size());
     m_pressLabel->move(0, 0);
@@ -104,8 +101,12 @@ DArrowButton::DArrowButton(QWidget *parent)
 }
 
 /*!
- * \~english \brief Set arrow direction of the button
- * \~chinese \brief 设置按钮的箭头方向
+  \brief Set arrow direction of the button.
+  \brief 设置按钮的箭头方向.
+
+  \a direction 箭头的方向.
+
+  \sa DArrowButton::ArrowDirection DArrowButton::arrowDirection()
  */
 void DArrowButton::setArrowDirection(ArrowDirection direction)
 {
@@ -114,8 +115,10 @@ void DArrowButton::setArrowDirection(ArrowDirection direction)
 }
 
 /*!
- * \~english \brief Get the arrow direction of the button.
- * \~chinese \brief 获取箭头方向
+  \brief Get the arrow direction of the button.
+  \brief 获取箭头方向.
+
+  \return 返回箭头方向.
  */
 int DArrowButton::arrowDirection() const
 {
@@ -123,8 +126,10 @@ int DArrowButton::arrowDirection() const
 }
 
 /*!
- * \~english \brief Set the button state.
- * \~chinese \brief 设置按钮状态
+  \brief Set the button state.
+  \brief 设置按钮状态
+
+  \a state 箭头按钮的状态.
  */
 void DArrowButton::setButtonState(ArrowButtonState state)
 {
@@ -133,8 +138,10 @@ void DArrowButton::setButtonState(ArrowButtonState state)
 }
 
 /*!
- * \~english \brief Get the button state
- * \~chinese \brief 获得按钮状态
+  \brief Get the button state
+  \brief 获得按钮状态
+
+  \return 返回按钮的状态.
  */
 int DArrowButton::buttonState() const
 {
@@ -212,50 +219,50 @@ void DArrowButton::initButtonState()
 }
 
 /*!
- * \enum DArrowButton::ArrowDirection
- *
- * \~english \brief The ArrowDirection enum indicate the direction of the arrow icon in the arrown button
- * \~chinese \brief DArrowButton::ArrowDirection 表示箭头图标的方向。
- *
- * \var DArrowButton::ArrowDirection DArrowButton::ArrowUp
- * \~english Up direction
- * \~chinese 箭头朝上
- *
- * \var DArrowButton::ArrowDirection DArrowButton::ArrowDown
- * \~english Down direction
- * \~chinese 箭头朝下
- *
- * \var DArrowButton::ArrowDirection DArrowButton::ArrowLeft
- * \~english Left direction
- * \~chinese 箭头朝左
- *
- * \var DArrowButton::ArrowDirection DArrowButton::ArrowRight
- * \~english Right direction
- * \~chinese 箭头朝右
+  \enum Dtk::Widget::DArrowButton::ArrowDirection
+  
+  \brief The ArrowDirection enum indicate the direction of the arrow icon in the arrown button
+  \brief DArrowButton::ArrowDirection 表示箭头图标的方向。
+  
+  \value ArrowUp
+  Up direction
+  箭头朝上
+  
+  \value ArrowDown
+  Down direction
+  箭头朝下
+  
+  \value ArrowLeft
+  Left direction
+  箭头朝左
+  
+  \value ArrowRight
+  Right direction
+  箭头朝右
  */
 
 /*!
- * \enum DArrowButton::ArrowButtonState
- *
- * \~english \brief The ArrowDirection enum indicate the direction of the arrow icon in the arrown button
- * \~chinese \brief DArrowButton::ArrowDirection 表示箭头图标的方向。
- *
- * \var DArrowButton::ArrowButtonState DArrowButton::ArrowStateNormal
- * \~english Normal state
- * \~chinese 普通状态
- *
- * \var DArrowButton::ArrowButtonState DArrowButton::ArrowStateHover
- * \~english Mouse hover state
- * \~chinese 鼠标在按钮上方悬停状态
- *
- * \var DArrowButton::ArrowButtonState DArrowButton::ArrowStatePress
- * \~english Button got pressed state
- * \~chinese 按钮被按下状态
+  \enum Dtk::Widget::DArrowButton::ArrowButtonState
+  
+  \brief The ArrowDirection enum indicate the direction of the arrow icon in the arrown button
+  \brief DArrowButton::ArrowDirection 表示箭头图标的方向。
+  
+  \value  ArrowStateNormal
+  Normal state
+  普通状态
+  
+  \value  ArrowStateHover
+  Mouse hover state
+  鼠标在按钮上方悬停状态
+  
+  \value  ArrowStatePress
+  Button got pressed state
+  按钮被按下状态
  */
 
 /*!
- * \~english \brief Update arrow direction of the button
- * \~chinese \brief 更新箭头按钮中箭头的方向
+  \brief Update arrow direction of the button
+  \brief 更新箭头按钮中箭头的方向
  */
 void DArrowButton::updateIconDirection(ArrowDirection direction)
 {
@@ -265,8 +272,8 @@ void DArrowButton::updateIconDirection(ArrowDirection direction)
 }
 
 /*!
- * \~english \brief Update icon state of the button
- * \~chinese \brief 更新箭头按钮中图标的状态
+  \brief Update icon state of the button
+  \brief 更新箭头按钮中图标的状态
  */
 void DArrowButton::updateIconState(ArrowButtonState state)
 {
