@@ -318,6 +318,8 @@ public:
         DCrumbTextFormat format = q->makeTextFormat();
 
         format.setText(tag_text);
+        if (currentText == tag_text)
+            format.setBackground(currentBrush);
         cursor.insertText(QString(QChar::ObjectReplacementCharacter), format);
     }
 
@@ -358,10 +360,15 @@ public:
             return false;
 
         DCrumbTextFormat format(cursor.charFormat());
+        currentText = format.text();
+        currentBrush = format.background();
 
         if (format.text().isEmpty())
             return false;
 
+        if (cursor.atEnd() && mousePos.x() > q->cursorRect().right())
+            return false;
+
         makeCrumb();
 
         if (mousePos.x() < q->cursorRect().left())
@@ -514,6 +521,8 @@ public:
     QMap<QString, DCrumbTextFormat> formats;
 
     bool dualClickMakeCrumb = false;
+    QString currentText;
+    QBrush currentBrush;
 
 public:
     QWidget* widgetTop;
@@ -604,7 +613,7 @@ QBrush CrumbObjectInterface::backgroundBrush(const QRect &rect, const QBrush &br
     DCrumbEdit 允许通过给定字符串的形式便捷的向其中添加一个默认样式的标签，也可以通过自行构建标签文字样式。请参见 insertCrumb()
     和 appendCrumb() 的不同重载。可以通过 crumbList() 获得当前标签输入控件中包含的标签列表。
 
-    \image DCrumbEdit.png
+    \image html DCrumbEdit.png
     \sa DCrumbTextFormat
 */
 
