@@ -29,6 +29,7 @@
 #include <QAction>
 #include <QRegularExpression>
 #include <DFontSizeManager>
+#include <DApplication>
 
 #include "private/ddialog_p.h"
 
@@ -43,8 +44,14 @@
 
 DWIDGET_BEGIN_NAMESPACE
 
-DDialogPrivate::DDialogPrivate(DDialog *qq) :
-    DAbstractDialogPrivate(qq)
+DDialogPrivate::DDialogPrivate(DDialog *qq)
+    : DAbstractDialogPrivate(qq)
+    , messageLabel(nullptr)
+    , titleLabel(nullptr)
+    , iconLayout(nullptr)
+    , contentLayout(nullptr)
+    , buttonLayout(nullptr)
+    , clickedButtonIndex(0)
 {
 
 }
@@ -95,8 +102,8 @@ void DDialogPrivate::init()
     QVBoxLayout *textLayout = new QVBoxLayout;
     textLayout->setContentsMargins(0, 0, 0, 0);
     textLayout->setSpacing(5);
-    textLayout->addWidget(titleLabel);
-    textLayout->addWidget(messageLabel, 0, Qt::AlignTop);
+    textLayout->addWidget(titleLabel, 0);
+    textLayout->addWidget(messageLabel, 1, Qt::AlignTop);
 
     // TopLayout--ContentLayout
     contentLayout = new QVBoxLayout;
@@ -104,6 +111,17 @@ void DDialogPrivate::init()
     contentLayout->setSpacing(0);
     contentLayout->addLayout(textLayout);
 
+    contentWidget = new QWidget;
+    contentWidget->setLayout(contentLayout);
+    DApplication *dapp = qobject_cast<DApplication*>(qApp);
+
+    if (dapp) {
+        contentWidget->setAttribute(Qt::WA_LayoutOnEntireRect, false);
+        contentWidget->setAttribute(Qt::WA_ContentsMarginsRespectsSafeArea, false);
+        contentWidget->setProperty("_dtk_NoTopLevelEnabled", true);
+        qApp->acclimatizeVirtualKeyboard(contentWidget);
+    }
+
     titleBar = new DTitlebar();
     titleBar->setAccessibleName("DDialogTitleBar");
     titleBar->setIcon(icon); //设置标题icon
@@ -118,7 +136,7 @@ void DDialogPrivate::init()
 
     // MainLayout--TopLayout
     mainLayout->addWidget(titleBar, 0, Qt::AlignTop);
-    mainLayout->addLayout(contentLayout);
+    mainLayout->addWidget(contentWidget);
     mainLayout->setContentsMargins(QMargins(0, 0, 0, 0));
 
     // MainLayout--ButtonLayout
@@ -230,11 +248,13 @@ void DDialogPrivate::_q_onButtonClicked()
     QAbstractButton *button = qobject_cast<QAbstractButton *>(q->sender());
 
     if (button) {
-        clickedButtonIndex = buttonList.indexOf(button);
-        q->buttonClicked(clickedButtonIndex, button->text());
+        int index = buttonList.indexOf(button);
+        q->buttonClicked(index, button->text());
 
-        if (onButtonClickedClose)
+        if (onButtonClickedClose) {
+            clickedButtonIndex = index;
             q->done(clickedButtonIndex);
+        }
     }
 }
 
@@ -251,45 +271,40 @@ void DDialogPrivate::_q_defaultButtonTriggered()
 }
 
 /*!
-    \~chinese \class DDialog
-    \~chinese \brief 可以使用 DDialog 类快速创建符合 DDE 风格的简要对话框窗口。
+    \class Dtk::Widget::DDialog
+    \inmodule dtkwidget
 
-    \~chinese \ingroup dialog-classes
-    \~chinese \ingroup abstractwidgets
+    \brief 可以使用 DDialog 类快速创建符合 DDE 风格的简要对话框窗口.
+    \brief Use DDialog class to create quick dialog window matched DDE style.
 
-    \~chinese DDialog 旨在提供简要的讯问式对话框的快速实现。提供了包含标题，对话框内容，默认图标，用以添加按钮的布局和一个可以自由添加内容的内容布局。
+    \ingroup dialog-classes
+    \ingroup abstractwidgets
+
+    DDialog 旨在提供简要的讯问式对话框的快速实现。提供了包含标题，对话框内容，默认图标，用以添加按钮的布局和一个可以自由添加内容的内容布局。
     可以使用 addButton() , insertButton(), setDefaultButton() 等函数方便的给对话框插入按钮并进行管理，可以使用 addContent(), insertContent()
     等函数操作内容布局。
 
-    \~chinese 此外， DDialog 还提供了一些额外的函数以供实现一些常见的需求。如，可以通过设置 setOnButtonClickedClose() 为 true 来使得用
+    此外， DDialog 还提供了一些额外的函数以供实现一些常见的需求。如，可以通过设置 setOnButtonClickedClose() 为 true 来使得用
     户在点击任何对话框上的按钮后关闭对话框。
 
-    \~chinese 当你需要快速构建较为简单结构的对话框，你应当使用 DDialog ，对于较为复杂的需求，请参阅 DAbstractDialog 或 QDialog 相关文档。
+    当你需要快速构建较为简单结构的对话框，你应当使用 DDialog ，对于较为复杂的需求，请参阅 DAbstractDialog 或 QDialog 相关文档。
 
-    \~chinese \sa DAbstractDialog, QDialog
-*/
+    \section1 differences Differences with QDialog
 
-/*!
-    \~english \class DDialog
-    \~english \brief Use DDialog class to create quick dialog window matched DDE style.
-
-    \~english \ingroup dialog-classes
-    \~english \ingroup abstractwidgets
-
-    \~english \section differences Differences with QDialog
-
-    \~english DDialog is designed to provide a easy way to create information dialog which include title, dialog content,
+    DDialog is designed to provide a easy way to create information dialog which include title, dialog content,
     dialog icon, buttons. You can use addButton() , insertButton() and related functions to insert buttons to the dialog
     easily, and use addContent(), insertContent() and related functions to manage the dialog's built-in content layout.
 
-    \~english DDialog also provided some extra function which maybe useful for some common use case, for example, you can
+    DDialog also provided some extra function which maybe useful for some common use case, for example, you can
     set setOnButtonClickedClose() to \c true , then once user clicked a button, the dialog will got closed.
 
-    \~english \sa DAbstractDialog, QDialog
+    \sa DAbstractDialog, QDialog
 */
 
 /*!
- * \~chinese \brief 构造一个 DDialog 对话框。
+  \brief 构造一个 DDialog 对话框.
+
+  \a parent 父控件指针.
  */
 DDialog::DDialog(QWidget *parent) :
     DAbstractDialog(*new DDialogPrivate(this), parent)
@@ -298,11 +313,11 @@ DDialog::DDialog(QWidget *parent) :
 }
 
 /*!
- * \~chinese \brief 构造一个 DDialog 对话框。
- *
- * \~chinese \param title 标题
- * \~chinese \param message 对话框消息
- * \~chinese \param parent 父控件
+  \brief 构造一个 DDialog 对话框。
+  
+  \a title 标题
+  \a message 对话框消息
+  \a parent 父控件
  */
 DDialog::DDialog(const QString &title, const QString &message, QWidget *parent) :
     DAbstractDialog(*new DDialogPrivate(this), parent)
@@ -314,11 +329,11 @@ DDialog::DDialog(const QString &title, const QString &message, QWidget *parent)
 }
 
 /*!
- * \~chinese \brief 通过按钮文字获取按钮下标
- *
- * \~chinese \param text 按钮文字
- *
- * \~chinese \return 按钮下标
+  \brief 通过按钮文字获取按钮下标.
+  
+  \a text 按钮文字
+  
+  \return 按钮下标
  */
 int DDialog::getButtonIndexByText(const QString &text) const
 {
@@ -335,7 +350,7 @@ int DDialog::getButtonIndexByText(const QString &text) const
 }
 
 /*!
- * \~chinese \brief 获得对话框包含的按钮数量
+  \brief 获得对话框包含的按钮数量.
  */
 int DDialog::buttonCount() const
 {
@@ -345,7 +360,7 @@ int DDialog::buttonCount() const
 }
 
 /*!
- * \~chinese \brief 获得对话框所含的所有内容控件的数量
+  \brief 获得对话框所含的所有内容控件的数量.
  */
 int DDialog::contentCount() const
 {
@@ -355,7 +370,7 @@ int DDialog::contentCount() const
 }
 
 /*!
- * \~chinese \brief 获得对话框的按钮列表
+  \brief 获得对话框的按钮列表
  */
 QList<QAbstractButton *> DDialog::getButtons() const
 {
@@ -365,7 +380,7 @@ QList<QAbstractButton *> DDialog::getButtons() const
 }
 
 /*!
- * \~chinese \brief 获得对话框所含的所有内容控件列表
+  \brief 获得对话框所含的所有内容控件列表
  */
 QList<QWidget *> DDialog::getContents() const
 {
@@ -375,10 +390,10 @@ QList<QWidget *> DDialog::getContents() const
 }
 
 /*!
- * \~chinese \brief 获得指定下标所对应的按钮
- *
- * \~chinese \param index 按钮下标
- * \~chinese \return 对应的按钮
+  \brief 获得指定下标所对应的按钮.
+  
+  \a index 按钮下标
+  \return 对应的按钮
  */
 QAbstractButton *DDialog::getButton(int index) const
 {
@@ -388,9 +403,9 @@ QAbstractButton *DDialog::getButton(int index) const
 }
 
 /*!
- * \~chinese \brief DDialog::getContent 获取指定下标对应的内容控件
- * \~chinese \param index　控件下标
- * \~chinese \return 返回对应的内容控件
+  \brief 获取指定下标对应的内容控件.
+  \a index　控件下标
+  \return 返回对应的内容控件
  */
 QWidget *DDialog::getContent(int index) const
 {
@@ -400,8 +415,9 @@ QWidget *DDialog::getContent(int index) const
 }
 
 /*!
- * \~chinese \brief DDialog::title
- * \~chinese \return 返回对话框的标题内容
+  \brief 返回对话框标题.
+
+  \return 返回对话框的标题内容
  */
 QString DDialog::title() const
 {
@@ -411,8 +427,9 @@ QString DDialog::title() const
 }
 
 /*!
- * \~chinese \brief DDialog::message
- * \~chinese \return 返回对话框的显示信息
+  \brief 返回对话框消息文本.
+
+  \return 返回对话框的显示信息
  */
 QString DDialog::message() const
 {
@@ -422,8 +439,9 @@ QString DDialog::message() const
 }
 
 /*!
- * \~chinese \brief DDialog::icon
- * \~chinese \return  返回对话框的icon
+  \brief 返回对话框图标.
+
+  \return  返回对话框的icon
  */
 QIcon DDialog::icon() const
 {
@@ -433,8 +451,8 @@ QIcon DDialog::icon() const
 }
 
 /*!
- * \~chinese \brief DDialog::iconPixmap
- * \~chinese \return 返回ICON的pixmap
+  \brief 返回对话框图标的 QPixmap 对象.
+  \return 返回ICON的pixmap
  */
 QPixmap DDialog::iconPixmap() const
 {
@@ -448,8 +466,9 @@ QPixmap DDialog::iconPixmap() const
 }
 
 /*!
- * \~chinese \brief DDialog::textFormat
- * \~chinese \return 返回设定的文本格式
+  \brief 返回对话框的文本格式.
+
+  \return 返回设定的文本格式
  */
 Qt::TextFormat DDialog::textFormat() const
 {
@@ -459,7 +478,9 @@ Qt::TextFormat DDialog::textFormat() const
 }
 
 /*!
- * \~chinese \brief 检查在点击任何按钮后是否都会关闭对话框。
+  \brief 检查在点击任何按钮后是否都会关闭对话框.
+
+  \return 关闭对话框返回 true , 否则返回 false.
  */
 bool DDialog::onButtonClickedClose() const
 {
@@ -469,8 +490,8 @@ bool DDialog::onButtonClickedClose() const
 }
 
 /*!
- * \~chinese \brief DDialog::setContentLayoutContentsMargins 设定内容布局的内容margin
- * \~chinese \param margins 具体的margins
+  \brief 设定内容布局的内容 margin .
+  \a margins 具体的 margins
  */
 void DDialog::setContentLayoutContentsMargins(const QMargins &margins)
 {
@@ -480,8 +501,9 @@ void DDialog::setContentLayoutContentsMargins(const QMargins &margins)
 }
 
 /*!
- * \~chinese \brief DDialog::contentLayoutContentsMargins
- * \~chinese \return 返回内容布局的内容margin
+  \brief 返回内容布局的边距.
+
+  \return 返回内容布局的内容margin
  */
 QMargins DDialog::contentLayoutContentsMargins() const
 {
@@ -491,8 +513,9 @@ QMargins DDialog::contentLayoutContentsMargins() const
 }
 
 /*!
- * \~chinese \brief DDialog::closeButtonVisible
- * \~chinese \return 返回关闭按钮是否可见的bool值
+  \brief 关闭按钮的可见属性.
+
+  \return 返回关闭按钮是否可见的bool值
  */
 bool DDialog::closeButtonVisible() const
 {
@@ -500,13 +523,13 @@ bool DDialog::closeButtonVisible() const
 }
 
 /*!
- * \~chinese \brief 向对话框添加按钮
- *
- * \~chinese \param text 按钮文字
- * \~chinese \param isDefault 是否默认按钮
- * \~chinese \param type 按钮类型
- *
- * \~chinese \return 所添加的按钮的下标
+  \brief 向对话框添加按钮.
+  
+  \a text 按钮文字
+  \a isDefault 是否默认按钮
+  \a type 按钮类型
+  
+  \return 所添加的按钮的下标
  */
 int DDialog::addButton(const QString &text, bool isDefault, ButtonType type)
 {
@@ -518,11 +541,11 @@ int DDialog::addButton(const QString &text, bool isDefault, ButtonType type)
 }
 
 /*!
- * \~chinese \brief 向对话框添加按钮
- *
- * \~chinese \param text 按钮文字
- *
- * \~chinese \return 所添加的按钮的下标
+  \brief 向对话框添加按钮.
+  
+  \a text 按钮文字
+  
+  \return 所添加的按钮的下标
  */
 int DDialog::addButtons(const QStringList &text)
 {
@@ -534,12 +557,12 @@ int DDialog::addButtons(const QStringList &text)
 }
 
 /*!
- * \~chinese \brief 向对话框插入按钮
- *
- * \~chinese \param index 下标
- * \~chinese \param text 按钮文字
- * \~chinese \param isDefault 是否是默认按钮
- * \~chinese \param type 按钮类型
+  \brief 向对话框插入按钮.
+  
+  \a index 下标
+  \a text 按钮文字
+  \a isDefault 是否是默认按钮
+  \a type 按钮类型
  */
 void DDialog::insertButton(int index, const QString &text, bool isDefault, ButtonType type)
 {
@@ -566,11 +589,11 @@ void DDialog::insertButton(int index, const QString &text, bool isDefault, Butto
 }
 
 /*!
- * \~chinese \brief 向对话框插入按钮
- *
- * \~chinese \param index 下标
- * \~chinese \param button 待插入的按钮
- * \~chinese \param isDefault 是否是默认按钮
+  \brief 向对话框插入按钮.
+  
+  \a index 下标
+  \a button 待插入的按钮
+  \a isDefault 是否是默认按钮
  */
 void DDialog::insertButton(int index, QAbstractButton *button, bool isDefault)
 {
@@ -616,10 +639,10 @@ void DDialog::insertButton(int index, QAbstractButton *button, bool isDefault)
 }
 
 /*!
- * \~chinese \brief 向对话框插入按钮
- *
- * \~chinese \param index 下标
- * \~chinese \param text 按钮文字
+  \brief 向对话框插入按钮.
+  
+  \a index 下标
+  \a text 按钮文字
  */
 void DDialog::insertButtons(int index, const QStringList &text)
 {
@@ -629,9 +652,9 @@ void DDialog::insertButtons(int index, const QStringList &text)
 }
 
 /*!
- * \~chinese \brief 从对话框移除按钮
- *
- * \~chinese \param index 待移除按钮的下标
+  \brief 从对话框移除按钮.
+  
+  \a index 待移除按钮的下标
  */
 void DDialog::removeButton(int index)
 {
@@ -665,9 +688,9 @@ void DDialog::removeButton(int index)
 }
 
 /*!
- * \~chinese \brief 从对话框移除按钮
- *
- * \~chinese \param button 待移除的按钮
+  \brief 从对话框移除按钮.
+  
+  \a button 待移除的按钮
  */
 void DDialog::removeButton(QAbstractButton *button)
 {
@@ -675,9 +698,9 @@ void DDialog::removeButton(QAbstractButton *button)
 }
 
 /*!
- * \~chinese \brief 从对话框移除按钮
- *
- * \~chinese \param text 待移除按钮的文本内容
+  \brief 从对话框移除按钮.
+  
+  \a text 待移除按钮的文本内容
  */
 void DDialog::removeButtonByText(const QString &text)
 {
@@ -688,7 +711,7 @@ void DDialog::removeButtonByText(const QString &text)
 }
 
 /*!
- * \~chinese \brief 清除所有按钮
+  \brief 清除所有按钮.
  */
 void DDialog::clearButtons()
 {
@@ -706,11 +729,10 @@ void DDialog::clearButtons()
 }
 
 /*!
- * \~chinese \brief 设置默认按钮
- *
- * \~chinese \param index 要设置的默认按钮的下标
- *
- * \~chinese \sa \ref default "默认按钮"
+  \brief 设置默认按钮.
+  
+  \a index 要设置的默认按钮的下标.
+  \return 设置成功返回 true，否则返回false.
  */
 bool DDialog::setDefaultButton(int index)
 {
@@ -723,11 +745,10 @@ bool DDialog::setDefaultButton(int index)
 }
 
 /*!
- * \~chinese \brief 设置默认按钮
- *
- * \~chinese \param str 要设置的默认按钮的文本内容
- *
- * \sa \ref default "默认按钮"
+  \brief 设置默认按钮.
+  
+  \a str 要设置的默认按钮的文本内容
+  \sa default
  */
 bool DDialog::setDefaultButton(const QString &str)
 {
@@ -735,11 +756,10 @@ bool DDialog::setDefaultButton(const QString &str)
 }
 
 /*!
- * \~chinese \brief 设置默认按钮
- *
- * \~chinese \param button 要设置的默认按钮
- *
- * \sa \ref default "默认按钮"
+  \brief 设置默认按钮
+  
+  \a button 要设置的默认按钮
+  \sa default
  */
 void DDialog::setDefaultButton(QAbstractButton *button)
 {
@@ -749,10 +769,10 @@ void DDialog::setDefaultButton(QAbstractButton *button)
 }
 
 /*!
- * \~chinese \brief 添加控件到对话框内容布局
- *
- * \~chinese \param widget 待添加的控件
- * \~chinese \param alignment 对齐方式
+  \brief 添加控件到对话框内容布局.
+  
+  \a widget 待添加的控件
+  \a alignment 对齐方式
  */
 void DDialog::addContent(QWidget *widget, Qt::Alignment alignment)
 {
@@ -764,11 +784,11 @@ void DDialog::addContent(QWidget *widget, Qt::Alignment alignment)
 }
 
 /*!
- * \~chinese \brief 在对话框内容布局指定位置插入控件
- *
- * \~chinese \param index 待插入的位置下标
- * \~chinese \param widget 待插入的控件
- * \~chinese \param alignment 对齐方式
+  \brief 在对话框内容布局指定位置插入控件.
+  
+  \a index 待插入的位置下标
+  \a widget 待插入的控件
+  \a alignment 对齐方式
  */
 void DDialog::insertContent(int index, QWidget *widget, Qt::Alignment alignment)
 {
@@ -780,10 +800,10 @@ void DDialog::insertContent(int index, QWidget *widget, Qt::Alignment alignment)
 }
 
 /*!
- * \~chinese \brief 从对话框内容布局中移除指定控件
- *
- * \~chinese \param widget 待移除的控件
- * \~chinese \param isDelete 是否执行删除
+  \brief 从对话框内容布局中移除指定控件.
+  
+  \a widget 待移除的控件
+  \a isDelete 是否执行删除
  */
 void DDialog::removeContent(QWidget *widget, bool isDelete)
 {
@@ -798,9 +818,9 @@ void DDialog::removeContent(QWidget *widget, bool isDelete)
 }
 
 /*!
- * \~chinese \brief 清空对话框内容布局中的所有内容
- *
- * \~chinese \param isDelete 是否删除
+  \brief 清空对话框内容布局中的所有内容.
+  
+  \a isDelete 是否删除
  */
 void DDialog::clearContents(bool isDelete)
 {
@@ -817,11 +837,11 @@ void DDialog::clearContents(bool isDelete)
 }
 
 /*!
- * \~chinese \brief 设置对话框内容间隔
- *
- * \~chinese 设置对话框的内容布局的间隔大小
- *
- * \sa QBoxLayout::setSpacing
+  \brief 设置对话框内容间隔.
+  
+  设置对话框的内容布局的间隔 \a spacing 大小
+  
+  \sa QBoxLayout::setSpacing
  */
 void DDialog::setSpacing(int spacing)
 {
@@ -831,11 +851,11 @@ void DDialog::setSpacing(int spacing)
 }
 
 /*!
- * \~chinese \brief 追加对话框内容间隔
- *
- * \~chinese 在对话框的内容布局后追加一个非弹性，大小为 \a spacing 的间隔（一个 QSpacerItem ）。
- *
- * \sa QBoxLayout::addSpacing
+  \brief 追加对话框内容间隔.
+  
+  在对话框的内容布局后追加一个非弹性，大小为 \a spacing 的间隔（一个 QSpacerItem ）。
+  
+  \sa QBoxLayout::addSpacing
  */
 void DDialog::addSpacing(int spacing)
 {
@@ -845,11 +865,12 @@ void DDialog::addSpacing(int spacing)
 }
 
 /*!
- * \~chinese \brief 插入对话框内容间隔
- *
- * \~chinese 在对话框的内容布局的指定位置插入一个非弹性，大小为 \a spacing 的间隔（一个 QSpacerItem ）。
- *
- * \sa QBoxLayout::insertSpacing
+  \brief 插入对话框内容间隔.
+  
+  在对话框的内容布局的指定位置插入一个非弹性，大小为 \a spacing 的间隔（一个 QSpacerItem ）。
+  \a index 插入间隔的索引位置.
+  
+  \sa QBoxLayout::insertSpacing
  */
 void DDialog::insertSpacing(int index, int spacing)
 {
@@ -859,9 +880,9 @@ void DDialog::insertSpacing(int index, int spacing)
 }
 
 /*!
- * \~chinese \brief 清除内容间隔
- *
- * \~chinese 清除对话框内容布局中包含的所有 QSpacerItem 。
+  \brief 清除内容间隔.
+  
+  清除对话框内容布局中包含的所有 QSpacerItem 。
  */
 void DDialog::clearSpacing()
 {
@@ -877,10 +898,10 @@ void DDialog::clearSpacing()
 }
 
 /*!
- * \~chinese \brief 设置按钮文字
- *
- * \~chinese \param index 需要设置文字的按钮的下标
- * \~chinese \param text 所需要设置的文字
+  \brief 设置按钮文字.
+  
+  \a index 需要设置文字的按钮的下标
+  \a text 所需要设置的文字
  */
 void DDialog::setButtonText(int index, const QString &text)
 {
@@ -890,9 +911,9 @@ void DDialog::setButtonText(int index, const QString &text)
 }
 
 /*!
- * \~chinese \brief 设置按钮图标
- * \~chinese \param index 需要设置图标的按钮的下标
- * \~chinese \param icon 所需要设置的图标
+  \brief 设置按钮图标.
+  \a index 需要设置图标的按钮的下标
+  \a icon 所需要设置的图标
  */
 void DDialog::setButtonIcon(int index, const QIcon &icon)
 {
@@ -902,7 +923,9 @@ void DDialog::setButtonIcon(int index, const QIcon &icon)
 }
 
 /*!
- * \~chinese \brief 设置对话框标题
+  \brief 设置对话框标题.
+
+  \a title 对话框标题.
  */
 void DDialog::setTitle(const QString &title)
 {
@@ -919,8 +942,9 @@ void DDialog::setTitle(const QString &title)
 }
 
 /*!
- * \~chinese \brief DDialog::setWordWrapTitle 设定标题Label内容是否可截断换行
- * \~chinese \param wordWrap true可换行　false不可以换行
+  \brief 设定标题Label内容是否可截断换行.
+
+  \a wordWrap true可换行　false不可以换行
  */
 void DDialog::setWordWrapTitle(bool wordWrap)
 {
@@ -929,7 +953,9 @@ void DDialog::setWordWrapTitle(bool wordWrap)
 }
 
 /*!
- * \~chinese \brief 设置对话框消息内容
+  \brief 设置对话框消息内容.
+
+  \a message 对话框消息.
  */
 void DDialog::setMessage(const QString &message)
 {
@@ -952,7 +978,8 @@ void DDialog::setWordWrapMessage(bool wordWrap)
 }
 
 /*!
- * \~chinese \brief 设置对话框图标
+  \brief 设置对话框图标.
+  \a icon 对话框图标.
  */
 void DDialog::setIcon(const QIcon &icon)
 {
@@ -966,9 +993,12 @@ void DDialog::setIcon(const QIcon &icon)
 }
 
 /*!
- * \~chinese \brief 设置对话框图标
- *
- * \~chinese 为对话框设置图标，同时可以指定一个期望的图标大小。
+  \brief 设置对话框图标.
+  \overload
+
+  为对话框设置图标，同时可以指定一个期望的图标大小。
+
+  \a icon 对话框图标 \a expectedSize 期望大小.
  */
 void DDialog::setIcon(const QIcon &icon, const QSize &expectedSize)
 {
@@ -986,7 +1016,9 @@ void DDialog::setIcon(const QIcon &icon, const QSize &expectedSize)
 }
 
 /*!
- * \~chinese \brief 设置对话框位图图标
+  \brief 设置对话框位图图标.
+
+  \a iconPixmap pixmap类型图标.
  */
 void DDialog::setIconPixmap(const QPixmap &iconPixmap)
 {
@@ -994,7 +1026,8 @@ void DDialog::setIconPixmap(const QPixmap &iconPixmap)
 }
 
 /*!
- * \~chinese \brief 设置文字格式
+  \brief 设置文字格式.
+  \a textFormat 文字格式.
  */
 void DDialog::setTextFormat(Qt::TextFormat textFormat)
 {
@@ -1011,9 +1044,9 @@ void DDialog::setTextFormat(Qt::TextFormat textFormat)
 }
 
 /*!
- * \~chinese \brief 设置是否在点击按钮后关闭对话框
- *
- * \~chinese 当设置为 true 后，无论点击什么按钮，都会在点击后关闭对话框。
+  \brief 设置是否在点击按钮后关闭对话框.
+  
+  当 \a onButtonClickedClose 设置为 true 后，无论点击什么按钮，都会在点击后关闭对话框。
  */
 void DDialog::setOnButtonClickedClose(bool onButtonClickedClose)
 {
@@ -1023,21 +1056,33 @@ void DDialog::setOnButtonClickedClose(bool onButtonClickedClose)
 }
 
 /*!
- * \~chinese \brief 以模态框形式显示当前对话框
- *
- * \~chinese 以 \l{QDialog#Modal Dialogs}{模态框} 形式显示当前对话框，将会阻塞直到用户关闭对话框，并返回 \DialogCode 结果。
- *
- * \sa open(), show(), result(), setWindowModality()
+  \brief 以模态框形式显示当前对话框.
+  
+  以 \l{QDialog#Modal Dialogs}{模态框} 形式显示当前对话框，将会阻塞直到用户关闭对话框。
+  
+  onButtonClickedClose()为 true 时返回当前点击按钮的Index，否则返回 结果。
+  \return 返回模态对话框处理的结果.
+
+  \sa QDialog::exec()
  */
 int DDialog::exec()
 {
     D_D(DDialog);
 
     d->clickedButtonIndex = -1;
+    int clickedIndex = d->clickedButtonIndex;
+
+    if (d->onButtonClickedClose) {
+        // 如果设置了WA_DeleteOnClose属性，那么在exec()中将直接delete this
+        // d->clickedButtonIndex中记录的数据失效，这里通过信号槽更新正确的数据
+        connect(this, &DDialog::buttonClicked, this, [ &clickedIndex ] (int index, const QString &) {
+                clickedIndex = index;
+        });
+    }
 
     int code = DAbstractDialog::exec();
 
-    return d->clickedButtonIndex >= 0 ? d->clickedButtonIndex : code;
+    return clickedIndex >= 0 ? clickedIndex : code;
 }
 
 void DDialog::setCloseButtonVisible(bool closeButtonVisible)
@@ -1127,7 +1172,7 @@ bool DDialog::eventFilter(QObject *watched, QEvent *event)
             if (label && !label->text().isEmpty() && label->wordWrap()) {
                 QSize sz = style()->itemTextRect(label->fontMetrics(), label->rect(), Qt::TextWordWrap, false, label->text()).size();
 
-                label->setMinimumHeight(qMax(sz.height(), label->height()));
+                label->setMinimumHeight(qMax(sz.height(), label->sizeHint().height()));
             }
         }
 
