@@ -2,7 +2,7 @@
  * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -30,107 +30,96 @@
 DWIDGET_BEGIN_NAMESPACE
 
 /*!
- * \~english \class DImageButton
- * \~english \brief The DImageButton class provides an easy way to create image based buttons.
- *
- * A DImageButton has four states: normal, hover, pressed and checked, developers
- * should provide at least the normal state image to get it to work properly.
+  \class Dtk::Widget::DImageButton
+  \inmodule dtkwidget
+
+  \brief The DImageButton class provides an easy way to create image based buttons.
+  \brief 在Deepin的程序设计中，用到了大量基于图片的按钮，而Qt的QPushButton不能方便的只使用图片，
+  每个项目都存在相同的自绘图片的按钮控件，所以Dtk提供了基于图片来构建的按钮。
+
+  A DImageButton has four states: normal, hover, pressed and checked, developers
+  should provide at least the normal state image to get it to work properly.
+
+  DImageButton 五个状态:
+  - 正常 DImageButton::State::Normal
+  - 鼠标移动在控件上 DImageButton::State::Hover
+  - 鼠标按下 DImageButton::State::Press
+  - 当前选中 DImageButton::State::Checked
+  - 禁用 DImageButton::State::Disabled
+  
+  \code
+  DImageButton *button = new DImageButton(":/normal.png", ":/hover.png", ":/press.png", this);
+  ...
+  connect(button, &DImageButton::clicked, ...);
+  \endcode
+*/
+/*!
+  \enum Dtk::Widget::DImageButton::State
+  DImageButton::State 定义了按钮可以使用的状态
+  
+  \value Normal
+  按钮默认状态图片 DImageButton::setNormalPic
+  
+  \value Hover
+  鼠标在按钮上时的图片 DImageButton::setHoverPic
+  
+  \value Press
+  按钮按下时的图片 DImageButton::setPressPic
+  
+  \value Checked
+  按钮选中的图片 DImageButton::setCheckedPic
+  
+  \value Disabled
+  按钮被禁用时的图片 DImageButton::setDisabledPic
  */
 
 /*!
- * \~english \brief DImageButton::DImageButton constructs an instance of DImageButton
- * \~english \param parent is the parent widget that the button will be attached to.
+  \fn void DImageButton::clicked()
+  \brief 当按钮被点击时会发出该信号
+ */
+/*!
+  \fn void DImageButton::checkedChanged(bool checked)
+  \brief 当按钮的选择状态 \a checked 发生改变时会发出该信号
+ */
+/*!
+  \fn void DImageButton::stateChanged()
+  \brief 当按钮的状态发生变化时会发出该信号
  */
 
 /*!
- * \~chinese \class DImageButton
- * \~chinese \brief 在Deepin的程序设计中，用到了大量基于图片的按钮，而Qt的QPushButton不能方便的只使用图片，
- * 每个项目都存在相同的自绘图片的按钮控件，所以Dtk提供了基于图片来构建的按钮。
- *
- * DImageButton 五个状态:
- * - 正常 DImageButton::State::Normal
- * - 鼠标移动在控件上 DImageButton::State::Hover
- * - 鼠标按下 DImageButton::State::Press
- * - 当前选中 DImageButton::State::Checked
- * - 禁用 DImageButton::State::Disabled
- *
- * \code
- * DImageButton *button = new DImageButton(":/normal.png", ":/hover.png", ":/press.png", this);
- * ...
- * connect(button, &DImageButton::clicked, ...);
- * \endcode
- *
- * \~chinese \enum DImageButton::State
- * DImageButton::State 定义了按钮可以使用的状态
- *
- * \~chinese \var DImageButton::Normal
- * 按钮默认状态图片 DImageButton::setNormalPic
- *
- * \~chinese \var DImageButton::Hover
- * 鼠标在按钮上时的图片 DImageButton::setHoverPic
- *
- * \~chinese \var DImageButton::Press
- * 按钮按下时的图片 DImageButton::setPressPic
- *
- * \~chinese \var DImageButton::Checked
- * 按钮选中的图片 DImageButton::setCheckedPic
- *
- * \~chinese \var DImageButton::Disabled
- * 按钮被禁用时的图片 DImageButton::setDisabledPic
- */
+  \brief DImageButton的默认构造函数
+  \brief DImageButton::DImageButton constructs an instance of DImageButton
 
-/*!
- * \fn DImageButton::clicked
- * \~chinese \brief 当按钮被点击时会发出该信号
- * \fn DImageButton::checkedChanged
- * \~chinese \brief 当按钮的选择状态发生改变时会发出该信号
- * \fn DImageButton::stateChanged
- * \~chinese \brief 当按钮的状态发生变化时会发出该信号
- */
-
-/*!
- * \~chinese \brief DImageButton的默认构造函数
- *
- * \param parent
+  \a parent is the parent widget that the button will be attached to.
  */
 DImageButton::DImageButton(QWidget *parent)
     : QLabel(parent)
     , DObject(*new DImageButtonPrivate(this))
 {
-    DThemeManager::registerWidget(this, QStringList({"checked", "state"}));
-
     D_D(DImageButton);
 
     d->updateIcon();
 }
 
 /*!
- * \~english \brief DImageButton::DImageButton This is an overloaded function.
- *
- * It's convinient to provide the images that used at the initialize stage.
- *
- * \param normalPic is the path of image to be used as the normal state.
- * \param hoverPic is the path of image to be used as the hover state.
- * \param pressPic is the path of image to be used as the pressed state.
- * \param parent is the parent widget that the button will be attached to.
- */
-
-/*!
- * \~chinese \brief 这是重载的构造函数
- *
- *  通过图片来初始化按钮
- *
- * \param normalPic 默认状态下的图片
- * \param hoverPic 鼠标在控件上的图片
- * \param pressPic 鼠标按下的图片
- * \param parent
+  \brief 这是重载的构造函数
+  \brief DImageButton::DImageButton This is an overloaded function.
+  
+  通过图片来初始化按钮
+  It's convinient to provide the images that used at the initialize stage.
+  
+  \a normalPic 默认状态下的图片
+  \a normalPic is the path of image to be used as the normal state.
+  \a hoverPic 鼠标在控件上的图片
+  \a hoverPic is the path of image to be used as the hover state.
+  \a pressPic 鼠标按下的图片
+  \a pressPic is the path of image to be used as the pressed state.
+  \a parent is the parent widget that the button will be attached to.
  */
 DImageButton::DImageButton(const QString &normalPic, const QString &hoverPic, const QString &pressPic, QWidget *parent)
     : QLabel(parent)
     , DObject(*new DImageButtonPrivate(this))
 {
-    DThemeManager::registerWidget(this, QStringList({"checked", "state"}));
-
     D_D(DImageButton);
 
     if (!normalPic.isEmpty()) {
@@ -149,35 +138,27 @@ DImageButton::DImageButton(const QString &normalPic, const QString &hoverPic, co
 }
 
 /*!
- * \~english \brief DImageButton::DImageButton This is an overloaded function.
- *
- * It's convinient to provide the images that used at the initialize stage.
- *
- * \param normalPic is the path of image to be used as the normal state.
- * \param hoverPic is the path of image to be used as the hover state.
- * \param pressPic is the path of image to be used as the pressed state.
- * \param checkedPic is the path of image to be used as the checked state.
- * \param parent is the parent widget that the button will be attached to.
- */
-
-/*!
- * \~chinese \brief 这是重载的构造函数
- *
- * 通过图片来初始化按钮
- *
- * \param normalPic 默认的图片
- * \param hoverPic 鼠标在控件上的图片
- * \param pressPic 鼠标按下的图片
- * \param checkedPic 选中时的图片
- * \param parent
+  \brief DImageButton::DImageButton This is an overloaded function.
+  
+  \brief 这是重载的构造函数
+  通过图片来初始化按钮
+  It's convinient to provide the images that used at the initialize stage.
+  
+  \a normalPic 默认的图片
+  \a normalPic is the path of image to be used as the normal state.
+  \a hoverPic 鼠标在控件上的图片
+  \a hoverPic is the path of image to be used as the hover state.
+  \a pressPic 鼠标按下的图片
+  \a pressPic is the path of image to be used as the pressed state.
+  \a checkedPic 选中时的图片
+  \a checkedPic is the path of image to be used as the checked state.
+  \a parent is the parent widget that the button will be attached to.
  */
 DImageButton::DImageButton(const QString &normalPic, const QString &hoverPic,
                            const QString &pressPic, const QString &checkedPic, QWidget *parent)
     : QLabel(parent)
     , DObject(*new DImageButtonPrivate(this))
 {
-    DThemeManager::registerWidget(this, QStringList({"checked", "state"}));
-
     D_D(DImageButton);
 
     if (!normalPic.isEmpty()) {
@@ -280,15 +261,14 @@ void DImageButton::mouseMoveEvent(QMouseEvent *event)
 }
 
 /*!
- * \~chinese \brief 设置是否启用按钮的功能
- *
- * 该方法和 DImageButton::setDisabled() 方法的作用相反，设置为False时则按钮的功能不可用，不能被点击和选中。
- *
- * \see DImageButton::setDisabled
- * \see DImageButton::isEnabled
- * \see DImageButton::enabled
- *
- * \param enabled
+  \brief 设置是否启用按钮的功能
+  
+  该方法和 DImageButton::setDisabled() 方法的作用相反，设置为False时则按钮的功能不可用，不能被点击和选中。
+  
+  \sa setDisabled()
+  \sa isEnabled()
+  
+  \a enabled
  */
 void DImageButton::setEnabled(bool enabled)
 {
@@ -303,14 +283,13 @@ void DImageButton::setEnabled(bool enabled)
 }
 
 /*!
- * \~chinese \brief 设置是否禁用按钮的功能
- *
- * 该方法和 DImageButton::setEnabled() 方法的作用相反，设置为True时则按钮的功能不可用，不能被点击和选中。
- *
- * \see DImageButton::setEnabled
- * \see DImageButton::disabled
- *
- * \param disabled
+  \brief 设置是否禁用按钮的功能
+  
+  该方法和 DImageButton::setEnabled() 方法的作用相反，设置为True时则按钮的功能不可用，不能被点击和选中。
+  
+  \sa setEnabled()
+  
+  \a disabled
  */
 void DImageButton::setDisabled(bool disabled)
 {
@@ -318,14 +297,14 @@ void DImageButton::setDisabled(bool disabled)
 }
 
 /*!
- * \~chinese \brief 设置按钮是否可以被选中
- *
- * 该方法默认值为false，如果要开启选中效果，则需要设置为True。
- *
- * \see DImageButton::checkable
- * \see DImageButton::isCheckable
- *
- * \param flag
+  \brief 设置按钮是否可以被选中
+  
+  该方法默认值为false，如果要开启选中效果，则需要设置为True。
+  
+  \sa DImageButton::checkable
+  \sa DImageButton::isCheckable
+  
+  \a flag
  */
 void DImageButton::setCheckable(bool flag)
 {
@@ -339,15 +318,15 @@ void DImageButton::setCheckable(bool flag)
 }
 
 /*!
- * \~chinese \brief 设置按钮的选中状态
- *
- * 如果DImageButton::setCheckable()没有被设置为true，则当前方法不可用。
- *
- * \param flag
- *
- * \see DImageButton::setCheckable
- * \see DImageButton::isChecked
- * \see DImageButton::checkedChanged
+  \brief 设置按钮的选中状态
+  
+  如果DImageButton::setCheckable()没有被设置为true，则当前方法不可用。
+  
+  \a flag
+  
+  \sa DImageButton::setCheckable
+  \sa DImageButton::isChecked
+  \sa DImageButton::checkedChanged
  */
 void DImageButton::setChecked(bool flag)
 {
@@ -368,30 +347,26 @@ void DImageButton::setChecked(bool flag)
 }
 
 /*!
- * \~english \property DImageButton::checked
- * \~english \brief This property indicates the DImageButton is in checked state of not.
+  \property DImageButton::checked
+
+  \brief 返回按钮现在是否为选中状态
+  \brief This property indicates the DImageButton is in checked state of not.
+  
+  \sa DImageButton::setChecked
+  \sa DImageButton::checkedChanged
+  
+  \return true 选中
+  \return false 未选中
  */
 
 /*!
- * \~chinese \property DImageButton::checked
- *
- * \~chinese \brief 返回按钮现在是否为选中状态
- *
- * \see DImageButton::setChecked
- * \see DImageButton::checkedChanged
- *
- * \return true 选中
- * \return false 未选中
- */
-
-/*!
- * \~chinese \brief 返回按钮是否是选中状态
- *
- * \see DImageButton::setChecked
- * \see DImageButton::checkedChanged
- *
- * \return true 选中状态
- * \return false 不是选中状态
+  \brief 返回按钮是否是选中状态
+  
+  \sa DImageButton::setChecked
+  \sa DImageButton::checkedChanged
+  
+  \return true 选中状态
+  \return false 不是选中状态
  */
 bool DImageButton::isChecked() const
 {
@@ -401,30 +376,26 @@ bool DImageButton::isChecked() const
 }
 
 /*!
- * \~english \property DImageButton::checkable
- * \~english \brief This property indicates the DImageButton can be checked or not.
+  \property DImageButton::checkable
+  
+  \brief 这个方法会返回按钮是否可以被选中
+  \brief This property indicates the DImageButton can be checked or not.
+  
+  \sa DImageButton::setCheckable
+  \sa DImageButton::isCheckable
+  
+  \return true 可以被选中
+  \return false 不可以被选中
  */
 
 /*!
- * \~chinese \property DImageButton::checkable
- *
- * \~chinese \brief 这个方法会返回按钮是否可以被选中
- *
- * \see DImageButton::setCheckable
- * \see DImageButton::isCheckable
- *
- * \return true 可以被选中
- * \return false 不可以被选中
- */
-
-/*!
- * \~chinese \brief 这个方法会返回按钮是否可以被选中
- *
- * \see DImageButton::setCheckable
- * \see DImageButton::checkable
- *
- * \return true
- * \return false
+  \brief 这个方法会返回按钮是否可以被选中
+  
+  \sa DImageButton::setCheckable
+  \sa DImageButton::checkable
+  
+  \return true
+  \return false
  */
 bool DImageButton::isCheckable() const
 {
@@ -434,12 +405,12 @@ bool DImageButton::isCheckable() const
 }
 
 /*!
- * \~chinese \brief 该方法用来设置默认状态下的图片
- *
- * \see DImageButton::normalPic
- * \see DImageButton::getNormalPic
- *
- * \param normalPicPixmap 图片的访问地址
+  \brief 该方法用来设置默认状态下的图片
+  
+  \sa DImageButton::normalPic
+  \sa DImageButton::getNormalPic
+  
+  \a normalPicPixmap 图片的访问地址
  */
 void DImageButton::setNormalPic(const QString &normalPicPixmap)
 {
@@ -450,12 +421,12 @@ void DImageButton::setNormalPic(const QString &normalPicPixmap)
 }
 
 /*!
- * \~chinese \brief 设置鼠标在控件上时的图片
- *
- * \see DImageButton::hoverPic
- * \see DImageButton::getHoverPic
- *
- * \param hoverPicPixmap 图片的访问地址
+  \brief 设置鼠标在控件上时的图片
+  
+  \sa DImageButton::hoverPic
+  \sa DImageButton::getHoverPic
+  
+  \a hoverPicPixmap 图片的访问地址
  */
 void DImageButton::setHoverPic(const QString &hoverPicPixmap)
 {
@@ -466,12 +437,12 @@ void DImageButton::setHoverPic(const QString &hoverPicPixmap)
 }
 
 /*!
- * \~chinese \brief 设置鼠标按下的图片
- *
- * \see DImageButton::pressPic
- * \see DImageButton::getPressPic
- *
- * \param pressPicPixmap 图片的访问地址
+  \brief 设置鼠标按下的图片
+  
+  \sa DImageButton::pressPic
+  \sa DImageButton::getPressPic
+  
+  \a pressPicPixmap 图片的访问地址
  */
 void DImageButton::setPressPic(const QString &pressPicPixmap)
 {
@@ -482,12 +453,12 @@ void DImageButton::setPressPic(const QString &pressPicPixmap)
 }
 
 /*!
- * \~chinese \brief 设置选中状态下的图片
- *
- * \see DImageButton::checkedPic
- * \see DImageButton::getCheckedPic
- *
- * \param checkedPicPixmap 图片的访问地址
+  \brief 设置选中状态下的图片
+  
+  \sa DImageButton::checkedPic
+  \sa DImageButton::getCheckedPic
+  
+  \a checkedPicPixmap 图片的访问地址
  */
 void DImageButton::setCheckedPic(const QString &checkedPicPixmap)
 {
@@ -498,12 +469,12 @@ void DImageButton::setCheckedPic(const QString &checkedPicPixmap)
 }
 
 /*!
- * \~chinese \brief 设置禁用状态下的图片
- *
- * \see DImageButton::disabledPic
- * \see DImageButton::getDisabledPic
- *
- * \param disabledPicPixmap 图片的访问地址
+  \brief 设置禁用状态下的图片
+  
+  \sa DImageButton::disabledPic
+  \sa DImageButton::getDisabledPic
+  
+  \a disabledPicPixmap 图片的访问地址
  */
 void DImageButton::setDisabledPic(const QString &disabledPicPixmap)
 {
@@ -514,28 +485,24 @@ void DImageButton::setDisabledPic(const QString &disabledPicPixmap)
 }
 
 /*!
- * \~english \property DImageButton::getNormalPic
- * \~english \brief This property holds the path of the image used as the normal state.
+  \property DImageButton::normalPic
+  
+  \brief 当前的默认状态图片
+  \brief This property holds the path of the image used as the normal state.
+  
+  \sa DImageButton::setNormalPic
+  \sa DImageButton::getNormalPic
+  
+  \return const QString
  */
 
 /*!
- * \~chinese \property DImageButton::normalPic
- *
- * \~chinese \brief 当前的默认状态图片
- *
- * \see DImageButton::setNormalPic
- * \see DImageButton::getNormalPic
- *
- * \return const QString
- */
-
-/*!
- * \~chinese \brief 返回默认状态的图片路径
- *
- * \see DImageButton::setNormalPic
- * \see DImageButton::normalPic
- *
- * \return const QString 默认状态图片的路径
+  \brief 返回默认状态的图片路径
+  
+  \sa DImageButton::setNormalPic
+  \sa DImageButton::normalPic
+  
+  \return const QString 默认状态图片的路径
  */
 const QString DImageButton::getNormalPic() const
 {
@@ -545,28 +512,24 @@ const QString DImageButton::getNormalPic() const
 }
 
 /*!
- * \~english \property DImageButton::getHoverPic
- * \~english \brief This property holds the path of the image used as the hover state.
+  \property DImageButton::hoverPic
+
+  \brief This property holds the path of the image used as the hover state.  
+  \brief 返回鼠标在控件上时的图片路径
+  
+  \sa DImageButton::setHoverPic
+  \sa DImageButton::getHoverPic
+  
+  \return const QString 图片路径
  */
 
 /*!
- * \~chinese \property DImageButton::hoverPic
- *
- * \~chinese \brief 返回鼠标在控件上时的图片路径
- *
- * \see DImageButton::setHoverPic
- * \see DImageButton::getHoverPic
- *
- * \return const QString 图片路径
- */
-
-/*!
- * \~chinese \brief 返回鼠标在按钮上时的图片路径
- *
- * \see DImageButton::setHoverPic
- * \see DImageButton::hoverPic
- *
- * \return const QString 图片路径
+  \brief 返回鼠标在按钮上时的图片路径
+  
+  \sa DImageButton::setHoverPic
+  \sa DImageButton::hoverPic
+  
+  \return const QString 图片路径
  */
 const QString DImageButton::getHoverPic() const
 {
@@ -576,28 +539,24 @@ const QString DImageButton::getHoverPic() const
 }
 
 /*!
- * \~english \property DImageButton::getPressPic
- * \~english \brief This property holds the path of the image used as the pressed state.
+  \property DImageButton::pressPic
+
+  \brief This property holds the path of the image used as the pressed state.
+  \brief 设置的鼠标按下时的图片
+  
+  \sa DImageButton::setPressPic
+  \sa DImageButton::getPressPic
+  
+  \return const QString 图片路径
  */
 
 /*!
- * \~chinese \property DImageButton::pressPic
- *
- * \~chinese \brief 设置的鼠标按下时的图片
- *
- * \see DImageButton::setPressPic
- * \see DImageButton::getPressPic
- *
- * \return const QString 图片路径
- */
-
-/*!
- * \~chinese \brief 返回鼠标按下时的图片
- *
- * \see DImageButton::pressPic
- * \see DImageButton::setPressPic
- *
- * \return const QString 图片路径
+  \brief 返回鼠标按下时的图片
+  
+  \sa DImageButton::pressPic
+  \sa DImageButton::setPressPic
+  
+  \return const QString 图片路径
  */
 const QString DImageButton::getPressPic() const
 {
@@ -607,28 +566,23 @@ const QString DImageButton::getPressPic() const
 }
 
 /*!
- * \~english \property DImageButton::getCheckedPic
- * \~english \brief This property holds the path of the image used as the checked state.
+  \property DImageButton::checkedPic
+
+  \brief This property holds the path of the image used as the checked state.
+  \brief 选中状态时的图片
+  
+  \return const QString 图片路径
+  \sa DImageButton::setCheckedPic
+  \sa DImageButton::getCheckedPic
  */
 
 /*!
- * \~chinese \property DImageButton::checkedPic
- *
- * \see DImageButton::setCheckedPic
- * \see DImageButton::getCheckedPic
- *
- * \~chinese \brief 选中状态时的图片
- *
- * \return const QString 图片路径
- */
-
-/*!
- * \~chinese \brief 返回选中状态时的图片
- *
- * \see DImageButton::setCheckedPic
- * \see DImageButton::checkedPic
- *
- * \return const QString 图片路径
+  \brief 返回选中状态时的图片
+  
+  \sa DImageButton::setCheckedPic
+  \sa DImageButton::checkedPic
+  
+  \return const QString 图片路径
  */
 const QString DImageButton::getCheckedPic() const
 {
@@ -638,23 +592,23 @@ const QString DImageButton::getCheckedPic() const
 }
 
 /*!
- * \~chinese \property DImageButton::disabledPic
- *
- * \~chinese \brief 禁用状态下的图片
- *
- * \see DImageButton::setDisabledPic
- * \see DImageButton::getDisabledPic
- *
- * \return const QString 图片路径
+  \property DImageButton::disabledPic
+  
+  \brief 禁用状态下的图片
+  
+  \sa DImageButton::setDisabledPic
+  \sa DImageButton::getDisabledPic
+  
+  \return const QString 图片路径
  */
 
 /*!
- * \~chinese \brief 返回禁用状态下的图片
- *
- * \see DImageButton::setDisabledPic
- * \see DImageButton::disabledPic
- *
- * \return const QString 图片路径
+  \brief 返回禁用状态下的图片
+  
+  \sa DImageButton::setDisabledPic
+  \sa DImageButton::disabledPic
+  
+  \return const QString 图片路径
  */
 const QString DImageButton::getDisabledPic() const
 {
@@ -664,17 +618,14 @@ const QString DImageButton::getDisabledPic() const
 }
 
 /*!
- * \~english \brief DImageButton::setState change the image by state
- * \~english \param state: see DImageButton::State
- */
-
-/*!
- * \~chinese \brief 设置当前的按钮状态
- *
- * \param state 当前的状态
- *
- * \see DImageButton::getState
- * \see DImageButton::stateChanged
+  \brief 设置当前的按钮状态
+  \brief DImageButton::setState change the image by state
+  
+  \a state 当前的状态
+  \a state: see DImageButton::State
+  
+  \sa DImageButton::getState
+  \sa DImageButton::stateChanged()
  */
 void DImageButton::setState(DImageButton::State state)
 {
@@ -683,19 +634,16 @@ void DImageButton::setState(DImageButton::State state)
     d->setState(state);
 }
 
-
 /*!
- * \~english \brief DImageButton::getState
- * \~english \return the state that the DImageButton is in.
- */
+  \brief DImageButton::getState
+  \brief 返回当前的按钮状态
 
-/*!
- * \~chinese \brief 返回当前的按钮状态
- *
- * \see DImageButton::setState
- * \see DImageButton::stateChanged
- *
- * \return DImageButton::State
+  
+  \sa DImageButton::setState
+  \sa DImageButton::stateChanged
+  
+  \return the state that the DImageButton is in.
+  \return DImageButton::State
  */
 DImageButton::State DImageButton::getState() const
 {
@@ -708,8 +656,6 @@ DImageButton::DImageButton(DImageButtonPrivate &q, QWidget *parent)
     : QLabel(parent)
     , DObject(q)
 {
-    DThemeManager::registerWidget(this, QStringList({"checked", "state"}));
-
     D_D(DImageButton);
 
     d->updateIcon();
