@@ -29,7 +29,7 @@ public:
         QVBoxLayout *layout = new QVBoxLayout(this);
         layout->setContentsMargins(layout->contentsMargins().left(), 0, layout->contentsMargins().right(), 0);
         layout->setSpacing(0);
-        label->setForegroundRole(QPalette::Highlight);
+        label->setForegroundRole(QPalette::ButtonText);
         layout->addWidget(label);
     }
 
@@ -48,7 +48,13 @@ public:
         if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
             p.setBackground(QColor(255, 255, 255));
         } else {
-            p.setBackground(QColor(109, 109, 109));
+            QColor bgColor(109, 109, 109);
+            if ((opt.state & QStyle::State_Active) == 0) {
+                auto inactive_mask_color = dp.color(QPalette::Window);
+                inactive_mask_color.setAlphaF(0.6);
+                bgColor = DGuiApplicationHelper::blendColor(bgColor, inactive_mask_color);
+            }
+            p.setBackground(bgColor);
         }
 
         p.setPen(QPen(dp.frameBorder(), opt.lineWidth));
