@@ -30,8 +30,8 @@
 #include <QEasingCurve>
 #include <QDebug>
 
-#include "dtkwidget_global.h"
-#include "dobject.h"
+#include <dtkwidget_global.h>
+#include <DObject>
 
 DWIDGET_BEGIN_NAMESPACE
 
