@@ -45,7 +45,12 @@ DMainWindowPrivate::DMainWindowPrivate(DMainWindow *qq)
 {
     titlebar = new DTitlebar(qq);
     titlebar->setAccessibleName("DMainWindowTitlebar");
-    if (DApplication::isDXcbPlatform() || (qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool())) {
+    auto noTitlebarEnabled = []{
+        QFunctionPointer enableNoTitlebar = qApp->platformFunction("_d_isEnableNoTitlebar");
+        bool enabled = qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
+        return enabled && enableNoTitlebar != nullptr;
+    };
+    if (DApplication::isDXcbPlatform() || noTitlebarEnabled()) {
         handle = new DPlatformWindowHandle(qq, qq);
         qq->setMenuWidget(titlebar);
     } else {
