@@ -81,6 +81,8 @@ public:
         QString str = qApp->translate("DSettingsDialog", "This shortcut conflicts with %1, click on Add to make this shortcut effective immediately")
                       .arg(QString("<span style=\"color: rgba(255, 90, 90, 1);\">%1 %2</span>").arg(text).arg(QString("[%1]").arg(edit->getKeySequence(key))));
         setMessage(str);
+        cancel->setAccessibleName("ChangeDDialogCancelButton");
+        replace->setAccessibleName("ChangeDDialogReplaceButton");
         insertButton(1, cancel);
         insertButton(1, replace);
         connect(replace, &DSuggestButton::clicked, [ = ] {  //替换
@@ -112,16 +114,18 @@ private:
 };
 
 /*!
- * \~chinese \class DSettingsWidgetFactory
- * \~chinese \brief DSettingsWidgetFactory是一个用于构造Deepin风格的设置对话框的控件。\n
- * \~chinese 对于每种控件，均由一个id和对应的构造函数来组成，DSettingsWidgetFactory内置了许多基础的控件，包括：\n
- * \~chinese checkbox/lineedit/combobox/spinbutton/buttongroup/radiogroup/slider等。
- * \~chinese
+  \class Dtk::Widget::DSettingsWidgetFactory
+  \inmodule dtkwidget
+  \brief DSettingsWidgetFactory是一个用于构造Deepin风格的设置对话框的控件.
+
+  对于每种控件，均由一个id和对应的构造函数来组成，DSettingsWidgetFactory内置了许多基础的控件，包括：
+  checkbox/lineedit/combobox/spinbutton/buttongroup/radiogroup/slider等。
+  
  */
 
 /*!
- * \~chinese \typedef DSettingsWidgetFactory::WidgetCreateHandler
- * \~chinese \brief 自定义的控件构建函数,一般接受一个 Dtk::Core::DSettingsOption 作为参数。\n
+  \typedef DSettingsWidgetFactory::WidgetCreateHandler
+  \brief 自定义的控件构建函数,一般接受一个 Dtk::Core::DSettingsOption 作为参数.
  */
 
 #define PRIVATE_PROPERTY_translateContext "_d_DSettingsWidgetFactory_translateContext"
@@ -136,12 +140,13 @@ static inline QString tr(const QByteArray &translateContext, const char *sourceT
 }
 
 /*!
- * \~chinese \brief DSettingsWidgetFactory::createTwoColumWidget 返回一个水平布局的控件，
- * \~chinese 左边为option的名称标签，右边为设置的自定义控件rightWidget
- * \~chinese \param option 设置项，包含改配置的名称
- * \~chinese \param rightWidget 自定义控件
- * \~chinese \return 生成的水平布局配置项控件
- * \~chinese \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translateContext, Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
+  \brief DSettingsWidgetFactory::createTwoColumWidget 返回一个水平布局的控件，
+  左边为option的名称标签，右边为设置的自定义控件rightWidget.
+
+  \a option 设置项，包含改配置的名称
+  \a rightWidget 自定义控件
+  \return 生成的水平布局配置项控件
+  \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translateContext, Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
  */
 QWidget *DSettingsWidgetFactory::createTwoColumWidget(DTK_CORE_NAMESPACE::DSettingsOption *option, QWidget *rightWidget)
 {
@@ -149,18 +154,20 @@ QWidget *DSettingsWidgetFactory::createTwoColumWidget(DTK_CORE_NAMESPACE::DSetti
 }
 
 /*!
- * \~chinese \brief DSettingsWidgetFactory::createTwoColumWidget 返回一个水平布局的控件，
- * \~chinese 左边为option的名称标签，右边为设置的自定义控件rightWidget, 可以通过translateContext设置翻译上下文。
- * \~chinese \param translateContext 自定义的翻译上下文，参考 QCoreApplication::translate();
- * \~chinese \param option 设置项，包含改配置的名称
- * \~chinese \param rightWidget 自定义控件
- * \~chinese \return 生成的水平布局配置项控件
- * \~chinese \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
+  \brief DSettingsWidgetFactory::createTwoColumWidget 返回一个水平布局的控件，
+  左边为option的名称标签，右边为设置的自定义控件rightWidget, 可以通过translateContext设置翻译上下文.
+
+  \a translateContext 自定义的翻译上下文，参考 QCoreApplication::translate();
+  \a option 设置项，包含改配置的名称
+  \a rightWidget 自定义控件
+  \return 生成的水平布局配置项控件
+  \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
  */
 QWidget *DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translateContext, DTK_CORE_NAMESPACE::DSettingsOption *option, QWidget *rightWidget)
 {
     auto optionFrame = new QWidget;
     optionFrame->setObjectName("OptionFrame");
+    optionFrame->setAccessibleName("OptionFrame");
 
     auto optionLayout = new QFormLayout(optionFrame);
     optionLayout->setContentsMargins(0, 0, 0, 0);
@@ -200,6 +207,7 @@ QPair<QWidget *, QWidget *> createShortcutEditOptionHandle(DSettingsWidgetFactor
     auto rightWidget = new KeySequenceEdit(option);
 
     rightWidget->setObjectName("OptionShortcutEdit");
+    rightWidget->setAccessibleName("OptionShortcutEdit");
     rightWidget->ShortcutDirection(Qt::AlignLeft);
 
     auto optionValue = option->value();
@@ -213,6 +221,7 @@ QPair<QWidget *, QWidget *> createShortcutEditOptionHandle(DSettingsWidgetFactor
 
         if (shortcutMap.value(keyseq)) {
             ChangeDDialog frame(keyseq, rightWidget, rightWidget->text());
+            frame.setAccessibleName("ChangeDDialog");
             frame.exec();
         } else {
             shortcutMap.remove(shortcutMap.key(rightWidget));
@@ -267,6 +276,7 @@ QPair<QWidget *, QWidget *> createCheckboxOptionHandle(QObject *opt)
     auto rightWidget = new QCheckBox(trName);
 
     rightWidget->setObjectName("OptionCheckbox");
+    rightWidget->setAccessibleName("OptionCheckbox");
     rightWidget->setChecked(option->value().toBool());
 
     option->connect(rightWidget, &QCheckBox::stateChanged,
@@ -290,6 +300,7 @@ QPair<QWidget *, QWidget *> createLineEditOptionHandle(QObject *opt)
     auto trName = DWIDGET_NAMESPACE::tr(translateContext, value.toStdString().c_str());
     auto rightWidget = new QLineEdit(trName);
     rightWidget->setObjectName("OptionLineEdit");
+    rightWidget->setAccessibleName("OptionLineEdit");
     rightWidget->setText(option->value().toString());
 
     option->connect(rightWidget, &QLineEdit::editingFinished,
@@ -312,6 +323,7 @@ QPair<QWidget *, QWidget *> createComboBoxOptionHandle(QObject *opt)
     auto rightWidget = new ComboBox();
     rightWidget->setFocusPolicy(Qt::StrongFocus);
     rightWidget->setObjectName("OptionLineEdit");
+    rightWidget->setAccessibleName("OptionComboBox");
 
     auto initComboxList = [ = ](const QStringList & data) {
         for (auto item : data) {
@@ -395,6 +407,7 @@ QPair<QWidget *, QWidget *> createButtonGroupOptionHandle(QObject *opt)
 
     auto rightWidget = new DButtonBox();
     rightWidget->setObjectName("OptionButtonBox");
+    rightWidget->setAccessibleName("OptionButtonBox");
     rightWidget->setButtonList(btnList, true);
     rightWidget->setMaximumWidth(60 * btnList.count());
     btnList.at(option->value().toInt())->setChecked(true);
@@ -423,6 +436,7 @@ QPair<QWidget *, QWidget *> createRadioGroupOptionHandle(QObject *opt)
     auto rightWidget = new QGroupBox;
     rightWidget->setContentsMargins(0, 0, 0, 0);
     rightWidget->setObjectName("OptionRadioGroup");
+    rightWidget->setAccessibleName("OptionRadioGroup");
     rightWidget->setAlignment(Qt::AlignLeft);
     rightWidget->setFlat(true);
     rightWidget->setMinimumHeight(24 * items.length() + 8);
@@ -436,6 +450,7 @@ QPair<QWidget *, QWidget *> createRadioGroupOptionHandle(QObject *opt)
         // fix 加大字体后显示截断，不应该 fixedheight
         rb->setMinimumHeight(24);
         rb->setProperty("_dtk_widget_settings_radiogroup_index", index);
+        rb->setAccessibleName(QString("OptionRadioButtonAt").append(QString::number(items.indexOf(item) + 1)));
         rgLayout->addWidget(rb);
         ++index;
 
@@ -470,8 +485,7 @@ QPair<QWidget *, QWidget *> createSpinButtonOptionHandle(QObject *opt)
     auto rightWidget = new QSpinBox();
     rightWidget->setButtonSymbols(QAbstractSpinBox::PlusMinus);
     rightWidget->setObjectName("OptionDSpinBox");
-    rightWidget->setValue(option->value().toInt());
-
+    rightWidget->setAccessibleName("OptionDSpinBox");
     if (option->data("max").isValid()) {
         rightWidget->setMaximum(option->data("max").toInt());
     }
@@ -479,6 +493,9 @@ QPair<QWidget *, QWidget *> createSpinButtonOptionHandle(QObject *opt)
         rightWidget->setMinimum(option->data("min").toInt());
     }
 
+    // The default range is 0-99. so we setMaximum/setMinimum first
+    rightWidget->setValue(option->value().toInt());
+
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
 
     option->connect(rightWidget, static_cast<void (QSpinBox::*)(int value)>(&QSpinBox::valueChanged),
@@ -499,6 +516,7 @@ QPair<QWidget *, QWidget *> createSliderOptionHandle(QObject *opt)
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
     auto rightWidget = new QSlider();
     rightWidget->setObjectName("OptionQSlider");
+    rightWidget->setAccessibleName("OptionQSlider");
     rightWidget->setOrientation(Qt::Horizontal);
     rightWidget->setMaximum(option->data("max").toInt());
     rightWidget->setMinimum(option->data("min").toInt());
@@ -526,6 +544,7 @@ QPair<QWidget *, QWidget *> createSwitchButton(QObject *opt)
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(opt);
     auto rightWidget = new DSwitchButton();
     rightWidget->setObjectName("OptionDSwitchButton");
+    rightWidget->setAccessibleName("OptionDSwitchButton");
     rightWidget->setChecked(option->value().toBool());
 
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
@@ -544,6 +563,7 @@ QPair<QWidget *, QWidget *> createSwitchButton(QObject *opt)
 
     QWidget *widget = new  QWidget();
     QHBoxLayout *layout = new QHBoxLayout(widget);
+    widget->setAccessibleName("OptionDSwitchButtonWidget");
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(rightWidget, 0, Qt::AlignRight);
 
@@ -558,6 +578,7 @@ QPair<QWidget *, QWidget *> createTitle1(QObject *opt)
 
     auto title = new ContentTitle;
     title->setTitle(trName);
+    title->setAccessibleName(trName);
     title->label()->setForegroundRole(QPalette::BrightText);
     DFontSizeManager::instance()->bind(title, DFontSizeManager::T4, QFont::Medium);
 
@@ -571,6 +592,7 @@ QPair<QWidget *, QWidget *> createTitle2(QObject *opt)
     auto trName = DWIDGET_NAMESPACE::tr(translateContext, option->value().toString().toLocal8Bit().constData());
 
     auto title = new ContentTitle;
+    title->setAccessibleName(trName);
     title->setTitle(trName);
     DFontSizeManager::instance()->bind(title, DFontSizeManager::T5, QFont::Medium);
 
@@ -583,6 +605,7 @@ QWidget *createUnsupportHandle(QObject *opt)
     auto rightWidget = new QLabel();
     rightWidget->setFixedHeight(24);
     rightWidget->setObjectName("OptionUnsupport");
+    rightWidget->setAccessibleName("OptionUnsupport");
     rightWidget->setText("Unsupport option type: " + option->viewType());
     rightWidget->setWordWrap(true);
 
@@ -626,9 +649,10 @@ DSettingsWidgetFactory::~DSettingsWidgetFactory()
 }
 
 /*!
- * \~chinese \brief DSettingsWidgetFactory::registerWidget 向Factory注册一种类型viewType。注册该类型后，可以通过在DSettings的DOption中，设置type为对应的viewType，这样Factory在构建viewType对应的控件时，会调用handler所指定的方法来构建。
- * \~chinese \param viewType 控件类型，建议为全局唯一的字符串，且不要和内部类型重复，参考 Dtk::Widget::DSettingsWidgetFactory
- * \~chinese \param handler 自定义的控件构建函数， 参考 Dtk::Widget::DSettingsWidgetFactory::WidgetCreateHandler
+  \brief DSettingsWidgetFactory::registerWidget 向Factory注册一种类型viewType。注册该类型后，可以通过在DSettings的DOption中，设置type为对应的viewType，这样Factory在构建viewType对应的控件时，会调用handler所指定的方法来构建.
+
+  \a viewType 控件类型，建议为全局唯一的字符串，且不要和内部类型重复，参考 Dtk::Widget::DSettingsWidgetFactory
+  \a handler 自定义的控件构建函数， 参考 Dtk::Widget::DSettingsWidgetFactory::WidgetCreateHandler
  */
 void DSettingsWidgetFactory::registerWidget(const QString &viewType, std::function<WidgetCreateHandler> handler)
 {
@@ -643,21 +667,23 @@ void DSettingsWidgetFactory::registerWidget(const QString &viewType, std::functi
 }
 
 /*!
- * \~chinese \brief DSettingsWidgetFactory::createWidget 创建一个option对应的配置控件，一般是需要自定义控件时使用，可以通过translateContext设置翻译上下文。
- * \~chinese \param option 需要构建的配置项
- * \~chinese \return 根据option的type属性创建的配置控件
- * \~chinese \sa Dtk::Widget::DSettingsWidgetFactory::createWidget(const QByteArray &translateContext, QPointer<Dtk::Core::DSettingsOption> option)
+  \brief DSettingsWidgetFactory::createWidget 创建一个option对应的配置控件，一般是需要自定义控件时使用，可以通过translateContext设置翻译上下文.
+
+  \a option 需要构建的配置项
+  \return 根据option的type属性创建的配置控件
+  \sa Dtk::Widget::DSettingsWidgetFactory::createWidget(const QByteArray &translateContext, QPointer<Dtk::Core::DSettingsOption> option)
  */
 QWidget *DSettingsWidgetFactory::createWidget(QPointer<DTK_CORE_NAMESPACE::DSettingsOption> option)
 {
     return createWidget(QByteArray(), option);
 }
 /*!
- * \~chinese \brief DSettingsWidgetFactory::createWidget 创建一个option对应的配置控件，一般是需要自定义控件时使用,
- * \~chinese \param translateContext 自定义的翻译上下文，参考 QCoreApplication::translate();
- * \~chinese \param option 需要构建的配置项
- * \~chinese \return 根据option的type属性创建的配置控件
- * \~chinese \sa Dtk::Widget::DSettingsWidgetFactory::createWidget(QPointer<Dtk::Core::DSettingsOption> option)
+  \brief DSettingsWidgetFactory::createWidget 创建一个option对应的配置控件，一般是需要自定义控件时使用.
+
+  \a translateContext 自定义的翻译上下文，参考 QCoreApplication::translate();
+  \a option 需要构建的配置项
+  \return 根据option的type属性创建的配置控件
+  \sa Dtk::Widget::DSettingsWidgetFactory::createWidget(QPointer<Dtk::Core::DSettingsOption> option)
  */
 QWidget *DSettingsWidgetFactory::createWidget(const QByteArray &translateContext, QPointer<DTK_CORE_NAMESPACE::DSettingsOption> option)
 {
