@@ -41,64 +41,68 @@ DWIDGET_BEGIN_NAMESPACE
 class DSimpleListViewPrivate : public DTK_CORE_NAMESPACE::DObjectPrivate
 {
 public:
-    DSimpleListViewPrivate(DSimpleListView *parent) : DObjectPrivate(parent)
-        {
-
-        }
+    DSimpleListViewPrivate(DSimpleListView *parent)
+        : DObjectPrivate(parent)
+    {
+    }
 
     QList<DSimpleListItem*> getSearchItems(QList<DSimpleListItem*> items);
     int getItemsTotalHeight();
     int getTopRenderOffset();
     void sortItemsByColumn(int column, bool descendingSort);
 
-    QPointer<DSimpleListItem> lastHoverItem;
-    QPointer<DSimpleListItem> lastSelectItem;
-    QPointer<DSimpleListItem> drawHoverItem;
-    QPointer<DSimpleListItem> mouseHoverItem;
-    QList<DSimpleListItem*> *listItems;
-    QList<DSimpleListItem*> *renderItems;
-    QList<DSimpleListItem*> *selectionItems;
-    QList<QString> columnTitles;
-    QList<SortAlgorithm> *sortingAlgorithms;
-    QList<bool> *sortingOrderes;
-    QList<int> columnWidths;
-    QString searchContent;
-    QTimer *hideScrollbarTimer;
-    SearchAlgorithm searchAlgorithm;
-    bool defaultSortingOrder;
-    bool mouseAtScrollArea;
-    bool mouseDragScrollbar;
-    bool drawFrame;
+    QPointer<DSimpleListItem> lastHoverItem = nullptr;
+    QPointer<DSimpleListItem> lastSelectItem = nullptr;
+    QPointer<DSimpleListItem> drawHoverItem = nullptr;
+    QPointer<DSimpleListItem> mouseHoverItem = nullptr;
+    QList<DSimpleListItem*> *listItems = nullptr;
+    QList<DSimpleListItem*> *renderItems = nullptr;
+    QList<DSimpleListItem*> *selectionItems = nullptr;
+    QList<QString> columnTitles = {};
+    QList<SortAlgorithm> *sortingAlgorithms = nullptr;
+    QList<bool> *sortingOrderes = nullptr;
+    QList<int> columnWidths = {};
+    QString searchContent = "";
+    QTimer *hideScrollbarTimer = nullptr;
+    SearchAlgorithm searchAlgorithm = nullptr;
+    bool defaultSortingOrder = false;
+    bool mouseAtScrollArea = false;
+    bool mouseDragScrollbar =false;
+    bool drawFrame = false;
     bool isKeepSelectWhenClickBlank;
-    bool isSingleSelect;
-    int alwaysVisibleColumn;
-    int clipRadius;
-    int defaultSortingColumn;
-    int hideScrollbarDuration;
-    int lastHoverColumnIndex;
-    int oldRenderOffset;
-    int renderOffset;
-    int rowHeight;
-    int scrollDistance;
-    int scrollStartY;
-    int scrollUnit;
-    int scrollbarDefaultWidth;
-    int scrollbarDragWidth;
-    int scrollbarMinHeight;
-    int scrollbarPadding;
-    int titleArrowPadding;
-    int titleHeight;
-    int titleHoverColumn;
-    int titlePadding;
-    int titlePressColumn;
+    bool isSingleSelect = false;
+    int alwaysVisibleColumn = 0;
+    int clipRadius = 0;
+    int defaultSortingColumn = 0;
+    int hideScrollbarDuration = 0;
+    int lastHoverColumnIndex = 0;
+    int oldRenderOffset = 0;
+    int renderOffset = 0;
+    int rowHeight = 0;
+    int scrollDistance = 0;
+    int scrollStartY = 0;
+    int scrollUnit = 0;
+    int scrollbarDefaultWidth = 0;
+    int scrollbarDragWidth = 0;
+    int scrollbarMinHeight = 0;
+    int scrollbarPadding = 0;
+    int titleArrowPadding = 0;
+    int titleHeight = 0;
+    int titleHoverColumn = 0;
+    int titlePadding = 0;
+    int titlePressColumn = 0;
 
     D_DECLARE_PUBLIC(DSimpleListView)
 };
 
 /*!
- * \~chinese \class DSimpleListView
- * \~chinese \brief DSimpleListView 是 deepin 基于 QWidget 从零绘制的列表控件。
- * \~chinese \brief 开发者只要懂得怎么使用 QPainter 进行图形绘制，开发者就可以在 DSimpleListItem 中绘制任意行内容，包括文本、图片、任意控件甚至每行都可以画一个小电影，而代码的复杂度不会随着绘制行内容而发生变化，所有的行内容都源于怎么使用 QPainter。
+  \class Dtk::Widget::DSimpleListView
+  \inmodule dtkwidget
+  \brief DSimpleListView 是 deepin 基于 QWidget 从零绘制的列表控件.
+
+  开发者只要懂得怎么使用 QPainter 进行图形绘制，开发者就可以在 DSimpleListItem 中绘制任意行内容，
+  包括文本、图片、任意控件甚至每行都可以画一个小电影，而代码的复杂度不会随着绘制行内容而发生变化，
+  所有的行内容都源于怎么使用 QPainter.
  */
 
 DSimpleListView::DSimpleListView(QWidget *parent) : QWidget(parent), DObject(*new DSimpleListViewPrivate(this))
@@ -189,7 +193,9 @@ DSimpleListView::~DSimpleListView()
 }
 
 /*!
- * \~chinese \brief 设置行高
+  \brief 设置行高.
+
+  \a height 行高.
  */
 void DSimpleListView::setRowHeight(int height)
 {
@@ -200,7 +206,9 @@ void DSimpleListView::setRowHeight(int height)
 }
 
 /*!
- * \~chinese \brief 设置列标题信息
+  \brief 设置列标题信息
+
+  \a titles 标题列表， \a widths 宽度列表, \a height 高度.
  */
 void DSimpleListView::setColumnTitleInfo(QList<QString> titles, QList<int> widths, int height)
 {
@@ -230,9 +238,9 @@ void DSimpleListView::setColumnTitleInfo(QList<QString> titles, QList<int> width
 }
 
 /*!
- * \~chinese \brief 设置列隐藏标志
- * \~chinese \param toggleHideFlags 用于控制列的隐藏标志，用于切换显示/隐藏。
- * \~chinese \param visibleColumnIndex 列始终可见的列索引，默认值为 -1，表示列始终不可见。
+  \brief 设置列隐藏标志
+  \a toggleHideFlags 用于控制列的隐藏标志，用于切换显示/隐藏。
+  \a visibleColumnIndex 列始终可见的列索引，默认值为 -1，表示列始终不可见。
  */
 void DSimpleListView::setColumnHideFlags(QList<bool> toggleHideFlags, int visibleColumnIndex)
 {
@@ -250,7 +258,9 @@ void DSimpleListView::setColumnHideFlags(QList<bool> toggleHideFlags, int visibl
 }
 
 /*!
- * \~chinese \brief 设置列排序算法
+  \brief 设置列排序算法.
+
+  \a algorithms 列排序算法 , \a sortColumn 排序的列项 , \a descendingSort 是否为降序排序.
  */
 void DSimpleListView::setColumnSortingAlgorithms(QList<SortAlgorithm> *algorithms, int sortColumn, bool descendingSort)
 {
@@ -269,7 +279,9 @@ void DSimpleListView::setColumnSortingAlgorithms(QList<SortAlgorithm> *algorithm
 }
 
 /*!
- * \~chinese \brief 设置搜索算法
+  \brief 设置搜索算法.
+
+  \a algorithm 搜索算法.
  */
 void DSimpleListView::setSearchAlgorithm(SearchAlgorithm algorithm)
 {
@@ -279,7 +291,9 @@ void DSimpleListView::setSearchAlgorithm(SearchAlgorithm algorithm)
 }
 
 /*!
- * \~chinese \brief 设置圆角半径
+  \brief 设置圆角半径.
+
+  \a radius 圆角大小.
  */
 void DSimpleListView::setClipRadius(int radius)
 {
@@ -289,10 +303,11 @@ void DSimpleListView::setClipRadius(int radius)
 }
 
 /*!
- * \~chinese \brief 设置边角细节
- * \~chinese \param enableFrame 是否绘制边角
- * \~chinese \param color 边角颜色
- * \~chinese \param opacity 不透明度
+  \brief 设置边角细节.
+
+  \a enableFrame 是否绘制边角
+  \a color 边角颜色
+  \a opacity 不透明度
  */
 void DSimpleListView::setFrame(bool enableFrame, QColor color, double opacity)
 {
@@ -304,7 +319,9 @@ void DSimpleListView::setFrame(bool enableFrame, QColor color, double opacity)
 }
 
 /*!
- * \~chinese \brief 添加 DSimpleListItem 列表到视图中
+  \brief 添加 DSimpleListItem 列表到视图中.
+
+  \a items 视图项列表.
  */
 void DSimpleListView::addItems(QList<DSimpleListItem*> items)
 {
@@ -325,7 +342,9 @@ void DSimpleListView::addItems(QList<DSimpleListItem*> items)
 }
 
 /*!
- * \~chinese \brief 删除一个列表项
+  \brief 删除一个列表项.
+
+  \a item 列表项指针.
  */
 void DSimpleListView::removeItem(DSimpleListItem* item)
 {
@@ -342,7 +361,7 @@ void DSimpleListView::removeItem(DSimpleListItem* item)
 }
 
 /*!
- * \~chinese \brief 删除所有列表项
+  \brief 删除所有列表项
  */
 void DSimpleListView::clearItems()
 {
@@ -356,8 +375,9 @@ void DSimpleListView::clearItems()
 }
 
 /*!
- * \~chinese \brief 添加 DSimpleListItem 列表以在视图中选择效果
- * \~chinese \param recordLastSelection 为 true 则清除最后一个选择项
+  \brief 添加 DSimpleListItem 列表以在视图中选择效果
+  \a recordLastSelection 为 true 则清除最后一个选择项
+  \a items 列表项.
  */
 void DSimpleListView::addSelections(QList<DSimpleListItem*> items, bool recordLastSelection)
 {
@@ -373,7 +393,9 @@ void DSimpleListView::addSelections(QList<DSimpleListItem*> items, bool recordLa
 }
 
 /*!
- * \~chinese \brief 移除所有选择项
+  \brief 移除所有选择项.
+
+  \a clearLastSelection 是否清除最后选中的列表项.
  */
 void DSimpleListView::clearSelections(bool clearLastSelection)
 {
@@ -388,7 +410,9 @@ void DSimpleListView::clearSelections(bool clearLastSelection)
 }
 
 /*!
- * \~chinese \brief 获取所有选择项
+  \brief 获取所有选择项.
+
+  \return 返回选中的列表项.
  */
 QList<DSimpleListItem*> DSimpleListView::getSelections()
 {
@@ -398,7 +422,9 @@ QList<DSimpleListItem*> DSimpleListView::getSelections()
 }
 
 /*!
- * \~chinese \brief 刷新所有项
+  \brief 刷新所有项.
+
+  \a items 列表项.
  */
 void DSimpleListView::refreshItems(QList<DSimpleListItem*> items)
 {
@@ -463,7 +489,9 @@ void DSimpleListView::refreshItems(QList<DSimpleListItem*> items)
 }
 
 /*!
- * \~chinese \brief 搜索
+  \brief 搜索.
+
+  \a content 被搜索内容.
  */
 void DSimpleListView::search(QString content)
 {
@@ -486,7 +514,9 @@ void DSimpleListView::search(QString content)
 }
 
 /*!
- * \~chinese \brief 设置单一选择
+  \brief 设置单一选择.
+
+  \a singleSelect 是否单一选择.
  */
 void DSimpleListView::setSingleSelect(bool singleSelect)
 {
@@ -496,7 +526,9 @@ void DSimpleListView::setSingleSelect(bool singleSelect)
 }
 
 /*!
- * \~chinese \brief 单击空白区域时保持选择项
+  \brief 单击空白区域时保持选择项.
+
+  \a keep 是否保持选中项.
  */
 void DSimpleListView::keepSelectWhenClickBlank(bool keep)
 {
@@ -506,7 +538,7 @@ void DSimpleListView::keepSelectWhenClickBlank(bool keep)
 }
 
 /*!
- * \~chinese \brief 选择所有列表项
+  \brief 选择所有列表项.
  */
 void DSimpleListView::selectAllItems()
 {
@@ -530,7 +562,7 @@ void DSimpleListView::selectAllItems()
 }
 
 /*!
- * \~chinese \brief 选择第一项
+  \brief 选择第一项.
  */
 void DSimpleListView::selectFirstItem()
 {
@@ -554,7 +586,7 @@ void DSimpleListView::selectFirstItem()
 }
 
 /*!
- * \~chinese \brief 选择最后一项
+  \brief 选择最后一项.
  */
 void DSimpleListView::selectLastItem()
 {
@@ -578,7 +610,7 @@ void DSimpleListView::selectLastItem()
 }
 
 /*!
- * \~chinese \brief 移动到上一项
+  \brief 移动到上一项.
  */
 void DSimpleListView::selectPrevItem()
 {
@@ -586,7 +618,7 @@ void DSimpleListView::selectPrevItem()
 }
 
 /*!
- * \~chinese \brief 移动到下一项
+  \brief 移动到下一项.
  */
 void DSimpleListView::selectNextItem()
 {
@@ -594,7 +626,7 @@ void DSimpleListView::selectNextItem()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到下一页的项
+  \brief 从当前项选择到下一页的项.
  */
 void DSimpleListView::shiftSelectPageDown()
 {
@@ -606,7 +638,7 @@ void DSimpleListView::shiftSelectPageDown()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到上一页的项
+  \brief 从当前项选择到上一页的项.
  */
 void DSimpleListView::shiftSelectPageUp()
 {
@@ -618,7 +650,7 @@ void DSimpleListView::shiftSelectPageUp()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到末尾项
+  \brief 从当前项选择到末尾项.
  */
 void DSimpleListView::shiftSelectToEnd()
 {
@@ -646,7 +678,7 @@ void DSimpleListView::shiftSelectToEnd()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到起始项
+  \brief 从当前项选择到起始项.
  */
 void DSimpleListView::shiftSelectToHome()
 {
@@ -674,7 +706,7 @@ void DSimpleListView::shiftSelectToHome()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到下一项
+  \brief 从当前项选择到下一项.
  */
 void DSimpleListView::shiftSelectToNext()
 {
@@ -686,7 +718,7 @@ void DSimpleListView::shiftSelectToNext()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到上一项
+  \brief 从当前项选择到上一项.
  */
 void DSimpleListView::shiftSelectToPrev()
 {
@@ -698,7 +730,7 @@ void DSimpleListView::shiftSelectToPrev()
 }
 
 /*!
- * \~chinese \brief 滚动到下一页
+  \brief 滚动到下一页.
  */
 void DSimpleListView::scrollPageDown()
 {
@@ -708,7 +740,7 @@ void DSimpleListView::scrollPageDown()
 }
 
 /*!
- * \~chinese \brief 滚动到上一页
+  \brief 滚动到上一页.
  */
 void DSimpleListView::scrollPageUp()
 {
