@@ -6,7 +6,7 @@
 
 #include <DObject>
 
-#include "dtkwidget_global.h"
+#include <dtkwidget_global.h>
 
 DWIDGET_BEGIN_NAMESPACE
 
