@@ -215,6 +215,12 @@ public:
         SP_DeleteButton,                            //删除按钮
         SP_AddButton,                               //新增按钮
         SP_TitleQuitFullButton,                     //标题栏(「」)
+        SP_TitleMoreButton,                         //标题栏 "更多" 按钮
+
+        SP_Title_SS_LeftButton,                     //标题栏左分屏按钮
+        SP_Title_SS_RightButton,                    //标题栏右分屏按钮
+        SP_Title_SS_ShowMaximizeButton,             //标题栏最大化分屏按钮
+        SP_Title_SS_ShowNormalButton,               //标题栏还原分屏按钮
         SP_CustomBase = QStyle::SP_CustomBase + 0xf00000
     };
 
@@ -229,6 +235,7 @@ public:
     static DStyle::StyleState getState(const QStyleOption *option);
     static void setFocusRectVisible(QWidget *widget, bool visible);
     static void setFrameRadius(QWidget *widget, int radius);
+    static void setUncheckedItemIndicatorVisible(QWidget *widget, bool visible);
     DStyle();
 
     static void drawPrimitive(const QStyle *style, DStyle::PrimitiveElement pe, const QStyleOption *opt, QPainter *p, const QWidget *w = nullptr);
