@@ -8,14 +8,15 @@
 DWIDGET_BEGIN_NAMESPACE
 
 /*!
- * \~chinese \class DSuggestButton
- * \~chinese \brief 这个控件提供了DTK中默认的按钮样式.
+  \class Dtk::Widget::DSuggestButton
+  \inmodule dtkwidget
+  \brief 这个控件提供了DTK中默认的按钮样式.
  */
 
 /*!
- * \~chinese \brief DSuggestButton的构造函数
- *
- * @param parent
+  \brief DSuggestButton的构造函数
+  
+  \a parent
  */
 DSuggestButton::DSuggestButton(QWidget *parent)
     : QPushButton(parent)
@@ -24,10 +25,10 @@ DSuggestButton::DSuggestButton(QWidget *parent)
 }
 
 /*!
- * \~chinese \brief DSuggestButton的重载构造函数，接收默认显示的文字
- *
- * @param text 默认显示的文字
- * @param parent
+  \brief DSuggestButton的重载构造函数，接收默认显示的文字
+  
+  \a text 默认显示的文字
+  \a parent
  */
 DSuggestButton::DSuggestButton(const QString &text, QWidget *parent)
     : QPushButton(text, parent)
