@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,25 +11,29 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DTITLEBAR_H
 #define DTITLEBAR_H
 
+#include <dtkwidget_global.h>
+#include <DObject>
+#include <DGuiApplicationHelper>
+
 #include <QFrame>
 #include <QMenu>
 
-#include <dobject.h>
-#include "dtkwidget_global.h"
-
+DGUI_USE_NAMESPACE
 DWIDGET_BEGIN_NAMESPACE
 
 class DTitlebarPrivate;
 class LIBDTKWIDGETSHARED_EXPORT DTitlebar : public QFrame, public DTK_CORE_NAMESPACE::DObject
 {
     Q_OBJECT
+    Q_PROPERTY(bool blurBackground READ blurBackground WRITE setBlurBackground)
+
 public:
     explicit DTitlebar(QWidget *parent = Q_NULLPTR);
 
@@ -40,7 +44,9 @@ public:
 
     QWidget *customWidget() const;
     void setCustomWidget(QWidget *, bool fixCenterPos = false);
-    void setCustomWidget(QWidget *, Qt::AlignmentFlag flag = Qt::AlignCenter, bool fixCenterPos = false);
+
+    void addWidget(QWidget *w, Qt::Alignment alignment = Qt::Alignment());
+    void removeWidget(QWidget *w);
 
     int buttonAreaWidth() const;
     bool separatorVisible() const;
@@ -48,23 +54,43 @@ public:
     bool autoHideOnFullscreen() const;
     void setAutoHideOnFullscreen(bool autohide);
 
-    void setVisible(bool visible) Q_DECL_OVERRIDE;
+    virtual void setVisible(bool visible) Q_DECL_OVERRIDE;
     void setEmbedMode(bool embed);
 
-    void resize(int width, int height);
-    void resize(const QSize &);
+    bool menuIsVisible() const;
+    void setMenuVisible(bool visible);
+
+    bool menuIsDisabled() const;
+    void setMenuDisabled(bool disabled);
+
+    bool quitMenuIsDisabled() const;
+    void setQuitMenuDisabled(bool disabled);
+    void setQuitMenuVisible(bool visible);
+
+    bool switchThemeMenuIsVisible() const;
+    void setSwitchThemeMenuVisible(bool visible);
 
     void setDisableFlags(Qt::WindowFlags flags);
     Qt::WindowFlags disableFlags() const;
+
+    void setSplitScreenEnabled(bool enabled);
+    bool splitScreenIsEnabled() const;
+
+    virtual QSize sizeHint() const override;
+    virtual QSize minimumSizeHint() const override;
+
+    bool blurBackground() const;
+    void setFullScreenButtonVisible(bool enabled);
+
 Q_SIGNALS:
     void optionClicked();
     void doubleClicked();
     void mousePressed(Qt::MouseButtons buttons);
-    void mouseMoving(Qt::MouseButton botton);
+    void mouseMoving(Qt::MouseButton button);
 
 #ifdef DTK_TITLE_DRAG_WINDOW
     void mousePosPressed(Qt::MouseButtons buttons, QPoint pos);
-    void mousePosMoving(Qt::MouseButton botton, QPoint pos);
+    void mousePosMoving(Qt::MouseButton button, QPoint pos);
 #endif
 
 public Q_SLOTS:
@@ -76,6 +102,8 @@ public Q_SLOTS:
     /// Maximized/Minumized
     void toggleWindowState();
 
+    void setBlurBackground(bool blurBackground);
+
 private Q_SLOTS:
 #ifndef QT_NO_MENU
     void showMenu();
@@ -83,6 +111,7 @@ private Q_SLOTS:
 
 protected:
     bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
+    bool event(QEvent *e) override;
     void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
     void mousePressEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
     void mouseReleaseEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
@@ -99,8 +128,10 @@ private:
 #ifndef QT_NO_MENU
     D_PRIVATE_SLOT(void _q_addDefaultMenuItems())
     D_PRIVATE_SLOT(void _q_helpActionTriggered())
+    D_PRIVATE_SLOT(void _q_feedbackActionTriggerd())
     D_PRIVATE_SLOT(void _q_aboutActionTriggered())
     D_PRIVATE_SLOT(void _q_quitActionTriggered())
+    D_PRIVATE_SLOT(void _q_switchThemeActionTriggered(QAction*))
 #endif
 };
 
