@@ -10,15 +10,18 @@
 DWIDGET_BEGIN_NAMESPACE
 
 /*!
- * \~chinese \class DToolTip
- * \~chinese \brief DToolTip类似于 QToolTip 功能的类
- * \~chinese \li DToolTip提供了将 DToolTip 显示在指定位置的函数
+  \class Dtk::Widget::DToolTip
+  \inmodule dtkwidget
+  \brief DToolTip类似于 QToolTip 功能的类.
+
+  DToolTip提供了将 DToolTip 显示在指定位置的函数
  */
 
 /*!
- * \~chinese \brief DToolTip的构造函数
- * \~chinese \param text文本信息
- * \~chinese \param completionClose提示消息消失后是否销毁
+  \brief DToolTip的构造函数.
+
+  \a text 文本信息
+  \a completionClose 提示消息消失后是否销毁
  */
 DToolTip::DToolTip(const QString &text, bool completionClose)
     : DTipLabel(text)
@@ -29,8 +32,9 @@ DToolTip::DToolTip(const QString &text, bool completionClose)
 }
 
 /*!
- * \~chinese \brief DToolTip::sizeHint
- * \~chinese \sa QLabel::sizeHint()
+  \brief DToolTip::sizeHint.
+
+  \sa QLabel::sizeHint()
  */
 QSize DToolTip::sizeHint() const
 {
@@ -43,9 +47,10 @@ QSize DToolTip::sizeHint() const
 }
 
 /*!
- * \chinese \brief DToolTip::show设置提示消息出现的位置
- * \chinese \param pos提示消息位置
- * \chinese \param duration提示消息存在时间，单位毫秒
+  \brief DToolTip::show设置提示消息出现的位置.
+
+  \a pos 提示消息位置
+  \a duration 提示消息存在时间，单位毫秒
  */
 void DToolTip::show(const QPoint &pos, int duration)
 {
