@@ -1,7 +1,7 @@
 #ifndef DFLOATINGMESSAGE_P_H
 #define DFLOATINGMESSAGE_P_H
 
-#include "dfloatingmessage.h"
+#include <DFloatingMessage>
 #include "dfloatingwidget_p.h"
 
 QT_BEGIN_NAMESPACE
@@ -30,7 +30,7 @@ public:
     MessageLabel *labMessage = nullptr;
     QWidget *content = nullptr;
     DIconButton *closeButton = nullptr;
-    DFloatingMessage::MessageType notifyType;
+    DFloatingMessage::MessageType notifyType = DFloatingMessage::MessageType::TransientType;
 
     D_DECLARE_PUBLIC(DFloatingMessage)
 };
