@@ -21,7 +21,7 @@
 #include <QPointer>
 #include <QFrame>
 
-#include "dtkwidget_global.h"
+#include <dtkwidget_global.h>
 
 DCORE_BEGIN_NAMESPACE
 class DSettings;
