@@ -1,7 +1,8 @@
 #!/bin/bash
 
-BUILD_DIR=build
-REPORT_DIR=report
+BUILD_DIR=`pwd`/../build-ut
+HTML_DIR=${BUILD_DIR}/html
+XML_DIR=${BUILD_DIR}/report
 
 cd ../
 #rm -rf $BUILD_DIR
@@ -24,7 +25,7 @@ mkdir $BUILD_DIR
 cd $BUILD_DIR
 qmake ../ CONFIG+=debug
 export ASAN_OPTIONS=halt_on_error=0
-TESTARGS="--gtest_output=xml:dde_test_report_dtkwidget.xml" make check -j$(nproc)
+TESTARGS="--gtest_output=xml:${XML_DIR}/report_dtkwidget.xml" make check -j$(nproc)
 
 lcov -d ./ -c -o coverage_all.info
 lcov --extract coverage_all.info $EXTRACT_ARGS --output-file coverage.info
@@ -54,8 +55,7 @@ filter_files=(
 "*/dbusinterface.*"
 "*/ddesktopservices_linux.cpp"
 )
-lcov --remove coverage_all.info "*/tests/*" "*/usr/include*" "*build/src*" ${filter_files[*]} --output-file coverage.info
-genhtml -o ../../tests/$REPORT_DIR coverage.info
+lcov --remove coverage_all.info "*/tests/*" "*/usr/include*" "*build-ut/src*" ${filter_files[*]} --output-file coverage.info
+genhtml -o $HTML_DIR $BUILD_DIR/coverage.info && mv ${BUILD_DIR}/html/index.html ${BUILD_DIR}/html/cov_dtkwidget.html
 
-cd ..
-test -e ./build/asan.log* && mv ./build/asan.log* ./build/asan_dtkwidget.log || touch ./build/asan.log
+test -e ${BUILD_DIR}/asan.log* && mv ${BUILD_DIR}/asan.log* ${BUILD_DIR}/asan_dtkwidget.log || touch ${BUILD_DIR}/asan_dtkwidget.log
